@@ -1,5 +1,5 @@
 /* A sort of clone of the cddlib test program `lcdd'.
-   Copyright (C) 2001-2008 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -91,6 +91,8 @@ typedef Polyhedron* POLYHEDRON_TYPE;
 #include <gmpxx.h>
 #include <vector>
 #include <set>
+#include <limits>
+#include <cassert>
 #include <cstdarg>
 #include <csignal>
 #include <cerrno>
@@ -104,8 +106,22 @@ typedef Polyhedron* POLYHEDRON_TYPE;
 
 #ifdef PPL_HAVE_GETOPT_H
 #include <getopt.h>
+
+// Try to accommodate non-GNU implementations of `getopt()'.
+#if !defined(no_argument) && defined(NO_ARG)
+#define no_argument NO_ARG
 #endif
 
+#if !defined(required_argument) && defined(REQUIRED_ARG)
+#define required_argument REQUIRED_ARG
+#endif
+
+#if !defined(optional_argument) && defined(OPTIONAL_ARG)
+#define optional_argument OPTIONAL_ARG
+#endif
+
+#endif // defined(PPL_HAVE_GETOPT_H)
+
 #ifdef PPL_HAVE_UNISTD_H
 // Include this for `getopt()': especially important if we do not have
 // <getopt.h>.
@@ -122,6 +138,11 @@ typedef Polyhedron* POLYHEDRON_TYPE;
 # include <sys/resource.h>
 #endif
 
+#if defined(PPL_HAVE_SYS_RESOURCE_H) \
+  && (defined(SA_ONESHOT) || defined(SA_RESETHAND))
+# define PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME
+#endif
+
 namespace {
 
 #ifdef PPL_HAVE_GETOPT_H
@@ -141,12 +162,14 @@ struct option long_options[] = {
 #endif
 
 static const char* usage_string
-= "Usage: %s [OPTION]... [FILE]...\n"
+= "Usage: %s [OPTION]... [FILE]\n"
 "Reads an H-representation (resp., a V-representation) of a polyhedron\n"
 "and generates a V-representation (resp., an H-representation) of\n"
 "the same polyhedron.\n\n"
 "Options:\n"
+#ifdef PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME
 "  -CSECS, --max-cpu=SECS  limits CPU usage to SECS seconds\n"
+#endif // defined(PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME)
 "  -RMB, --max-memory=MB   limits memory usage to MB megabytes\n"
 "  -h, --help              prints this help text to stdout\n"
 "  -oPATH, --output=PATH   appends output to PATH\n"
@@ -171,7 +194,10 @@ static const char* usage_string
 
 const char* program_name = 0;
 
+#ifdef PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME
 unsigned long max_seconds_of_cpu_time = 0;
+#endif // defined(PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME)
+
 unsigned long max_bytes_of_virtual_memory = 0;
 bool print_timings = false;
 bool verbose = false;
@@ -267,6 +293,8 @@ warning(const char* format, ...) {
   va_end(ap);
 }
 
+#ifdef PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME
+
 extern "C" typedef void (*sig_handler_type)(int);
 
 void
@@ -282,7 +310,7 @@ set_alarm_on_cpu_time(const unsigned seconds, sig_handler_type handler) {
 #elif defined(SA_RESETHAND)
   s.sa_flags = SA_RESETHAND;
 #else
-  #error "Either SA_ONESHOT or SA_RESETHAND must be defined."
+# error "Either SA_ONESHOT or SA_RESETHAND must be defined."
 #endif
 
   if (sigaction(SIGXCPU, &s, 0) != 0)
@@ -299,7 +327,10 @@ set_alarm_on_cpu_time(const unsigned seconds, sig_handler_type handler) {
   }
 }
 
+#endif // PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME
+
 #if PPL_HAVE_DECL_RLIMIT_AS
+
 void
 limit_virtual_memory(const unsigned bytes) {
   struct rlimit t;
@@ -313,10 +344,13 @@ limit_virtual_memory(const unsigned bytes) {
       fatal("setrlimit failed: %s", strerror(errno));
   }
 }
+
 #else
+
 void
 limit_virtual_memory(unsigned) {
 }
+
 #endif // !PPL_HAVE_DECL_RLIMIT_AS
 
 extern "C" void
@@ -365,6 +399,8 @@ process_options(int argc, char* argv[]) {
       exit(0);
       break;
 
+#ifdef PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME
+
     case 'C':
       l = strtol(optarg, &endptr, 10);
       if (*endptr || l < 0)
@@ -373,6 +409,8 @@ process_options(int argc, char* argv[]) {
 	max_seconds_of_cpu_time = l;
       break;
 
+#endif // defined(PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME)
+
     case 'R':
       l = strtol(optarg, &endptr, 10);
       if (*endptr || l < 0)
@@ -1141,9 +1179,13 @@ main(int argc, char* argv[]) try {
   // Process command line options.
   process_options(argc, argv);
 
+#ifdef PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME
+
   if (max_seconds_of_cpu_time > 0)
     set_alarm_on_cpu_time(max_seconds_of_cpu_time, timeout);
 
+#endif // defined(PPL_LCDD_SUPPORTS_LIMIT_ON_CPU_TIME)
+
   if (max_bytes_of_virtual_memory > 0)
     limit_virtual_memory(max_bytes_of_virtual_memory);
 
