@@ -1,5 +1,5 @@
 (* OCaml interface: domain-independent functions.
-   Copyright (C) 2001-2008 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -22,6 +22,26 @@ site: http://www.cs.unipr.it/ppl/ . *)
 
 open Gmp
 
+exception PPL_arithmetic_overflow of string
+let _ = Callback.register_exception "PPL_arithmetic_overflow"
+          (PPL_arithmetic_overflow "any string")
+
+exception PPL_timeout_exception
+let _ = Callback.register_exception "PPL_timeout_exception"
+          (PPL_timeout_exception)
+
+exception PPL_internal_error of string
+let _ = Callback.register_exception "PPL_internal_error"
+          (PPL_internal_error "any string")
+
+exception PPL_unknown_standard_exception of string
+let _ = Callback.register_exception "PPL_unknown_standard_exception"
+          (PPL_unknown_standard_exception "any string")
+
+exception PPL_unexpected_error of string
+let _ = Callback.register_exception "PPL_unexpected_error"
+          (PPL_unexpected_error "any string")
+
 type degenerate_element =
     Universe
   | Empty
@@ -117,23 +137,47 @@ unit -> string = "ppl_version"
 external ppl_banner:
 unit -> string = "ppl_banner"
 
+external ppl_io_wrap_string:
+string -> int -> int -> int -> string = "ppl_io_wrap_string"
+
+external ppl_max_space_dimension:
+unit -> int = "ppl_max_space_dimension"
+
+external ppl_Coefficient_is_bounded:
+unit -> bool = "ppl_Coefficient_is_bounded"
+
+external ppl_Coefficient_max:
+unit -> Z.t = "ppl_Coefficient_max"
+
+external ppl_Coefficient_min:
+unit -> Z.t = "ppl_Coefficient_min"
+
 external ppl_set_rounding_for_PPL:
 unit -> unit = "ppl_set_rounding_for_PPL"
 
 external ppl_restore_pre_PPL_rounding:
 unit -> unit = "ppl_restore_pre_PPL_rounding"
 
+external ppl_set_timeout:
+int -> unit = "ppl_set_timeout"
+
+external ppl_reset_timeout:
+unit -> unit = "ppl_reset_timeout"
+
 external ppl_new_MIP_Problem_from_space_dimension:
   int -> mip_problem = "ppl_new_MIP_Problem_from_space_dimension"
 
 external ppl_new_MIP_Problem:
-      int -> constraint_system -> linear_expression
-	-> optimization_mode -> mip_problem
-	  = "ppl_new_MIP_Problem"
+  int -> constraint_system -> linear_expression
+    -> optimization_mode -> mip_problem
+      = "ppl_new_MIP_Problem"
 
 external ppl_MIP_Problem_space_dimension:
   mip_problem -> int = "ppl_MIP_Problem_space_dimension"
 
+external ppl_MIP_Problem_integer_space_dimensions:
+  mip_problem -> int list = "ppl_MIP_Problem_integer_space_dimensions"
+
 external ppl_MIP_Problem_constraints:
   mip_problem -> constraint_system = "ppl_MIP_Problem_constraints"
 
@@ -212,3 +256,7 @@ external ppl_MIP_Problem_get_control_parameter:
 external ppl_MIP_Problem_swap:
   mip_problem -> mip_problem -> unit
       = "ppl_MIP_Problem_swap"
+
+external ppl_MIP_Problem_ascii_dump:
+  mip_problem -> string
+      = "ppl_MIP_Problem_ascii_dump"
