@@ -1,11 +1,11 @@
 /* Congruence_System class implementation (non-inline functions).
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -20,7 +20,7 @@ Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 For the most up-to-date information see the Parma Polyhedra Library
 site: http://www.cs.unipr.it/ppl/ . */
 
-#include <config.h>
+#include <ppl-config.h>
 
 #include "Congruence_System.defs.hh"
 #include "Congruence_System.inlines.hh"
@@ -38,7 +38,7 @@ site: http://www.cs.unipr.it/ppl/ . */
 namespace PPL = Parma_Polyhedra_Library;
 
 PPL::Congruence_System::Congruence_System(const Constraint_System& cs)
-  : Matrix(0, 2) {
+  : Matrix(0, cs.space_dimension() + 2) {
   for (Constraint_System::const_iterator i = cs.begin(),
 	 cs_end = cs.end(); i != cs_end; ++i)
     if (i->is_equality())
@@ -50,18 +50,19 @@ PPL::Congruence_System::
 increase_space_dimension(const dimension_type new_space_dim) {
   assert(space_dimension() <= new_space_dim);
 
-  dimension_type cols_to_add = new_space_dim - space_dimension();
+  const dimension_type cols_to_add = new_space_dim - space_dimension();
 
-  if (cols_to_add)
+  if (cols_to_add) {
     if (num_rows()) {
-      dimension_type old_num_cols = num_columns();
+      const dimension_type old_num_columns = num_columns();
       add_zero_columns(cols_to_add);
       // Move the moduli.
-      swap_columns(num_columns() - 1, old_num_cols - 1);
+      swap_columns(num_columns() - 1, old_num_columns - 1);
     }
     else
       // Empty system.
       add_zero_columns(cols_to_add);
+  }
 
   assert(OK());
   return true;
@@ -75,7 +76,7 @@ PPL::Congruence_System::insert_verbatim(const Congruence& cg) {
   if (cg_size > old_num_columns) {
     // Resize the system, if necessary.
     add_zero_columns(cg_size - old_num_columns);
-    if (num_rows() != 0)
+    if (!has_no_rows())
       // Move the moduli to the last column.
       swap_columns(old_num_columns - 1, cg_size - 1);
     add_row(cg);
@@ -96,7 +97,7 @@ PPL::Congruence_System::insert_verbatim(const Congruence& cg) {
 
 void
 PPL::Congruence_System::insert(const Constraint& c) {
-  dimension_type cg_size = c.space_dimension() + 2;
+  const dimension_type cg_size = c.space_dimension() + 2;
   const dimension_type old_num_columns = num_columns();
   if (cg_size < old_num_columns) {
     // Create a congruence of the required size from `c'.
@@ -107,7 +108,7 @@ PPL::Congruence_System::insert(const Constraint& c) {
     if (cg_size > old_num_columns) {
       // Resize the system, if necessary.
       add_zero_columns(cg_size - old_num_columns);
-      if (num_rows() != 0)
+      if (!has_no_rows())
 	// Move the moduli to the last column.
 	swap_columns(old_num_columns - 1, cg_size - 1);
     }
@@ -123,18 +124,18 @@ void
 PPL::Congruence_System::recycling_insert(Congruence_System& cgs) {
   const dimension_type old_num_rows = num_rows();
   const dimension_type cgs_num_rows = cgs.num_rows();
-  const dimension_type old_num_cols = num_columns();
-  dimension_type cgs_num_cols = cgs.num_columns();
-  if (old_num_cols >= cgs_num_cols)
+  const dimension_type old_num_columns = num_columns();
+  dimension_type cgs_num_columns = cgs.num_columns();
+  if (old_num_columns >= cgs_num_columns)
     add_zero_rows(cgs_num_rows, Row::Flags());
   else {
     add_zero_rows_and_columns(cgs_num_rows,
-			      cgs_num_cols - old_num_cols,
+			      cgs_num_columns - old_num_columns,
 			      Row::Flags());
     // Swap the modulus column into the new last column.
-    swap_columns(old_num_cols - 1, num_columns() - 1);
+    swap_columns(old_num_columns - 1, num_columns() - 1);
   }
-  --cgs_num_cols; // Convert to modulus index.
+  --cgs_num_columns; // Convert to modulus index.
   const dimension_type mod_index = num_columns() - 1;
   for (dimension_type i = cgs_num_rows; i-- > 0; ) {
     // Swap one coefficient at a time into the newly added rows, instead
@@ -142,9 +143,9 @@ PPL::Congruence_System::recycling_insert(Congruence_System& cgs) {
     // have the same capacities as the existing rows.
     Congruence& new_cg = operator[](old_num_rows + i);
     Congruence& old_cg = cgs[i];
-    for (dimension_type j = cgs_num_cols; j-- > 0; )
+    for (dimension_type j = cgs_num_columns; j-- > 0; )
       std::swap(new_cg[j], old_cg[j]);
-    std::swap(new_cg[mod_index], old_cg[cgs_num_cols]); // Modulus.
+    std::swap(new_cg[mod_index], old_cg[cgs_num_columns]); // Modulus.
   }
 
   assert(OK());
@@ -154,29 +155,29 @@ void
 PPL::Congruence_System::insert(const Congruence_System& y) {
   Congruence_System& x = *this;
 
-  const dimension_type x_n_rows = x.num_rows();
-  const dimension_type y_n_rows = y.num_rows();
-  const dimension_type old_n_cols = x.num_columns();
-  const dimension_type y_n_cols = y.num_columns();
+  const dimension_type x_num_rows = x.num_rows();
+  const dimension_type y_num_rows = y.num_rows();
+  const dimension_type old_num_columns = x.num_columns();
+  const dimension_type y_num_columns = y.num_columns();
   // Grow to the required size.
-  if (old_n_cols >= y_n_cols)
-    add_zero_rows(y_n_rows, Row::Flags());
+  if (old_num_columns >= y_num_columns)
+    add_zero_rows(y_num_rows, Row::Flags());
   else {
-    add_zero_rows_and_columns(y_n_rows,
-			      y_n_cols - old_n_cols,
+    add_zero_rows_and_columns(y_num_rows,
+			      y_num_columns - old_num_columns,
 			      Row::Flags());
     // Swap the modulus column into the new last column.
-    swap_columns(old_n_cols - 1, num_columns() - 1);
+    swap_columns(old_num_columns - 1, num_columns() - 1);
   }
 
   // Copy the rows of `y', forcing size and capacity.
   const dimension_type x_mod_index = x.num_columns() - 1;
-  const dimension_type y_mod_index = y_n_cols - 1;
-  for (dimension_type i = y_n_rows; i-- > 0; ) {
+  const dimension_type y_mod_index = y_num_columns - 1;
+  for (dimension_type i = y_num_rows; i-- > 0; ) {
     Row copy(y[i], x.row_size, x.row_capacity);
     // Swap the modulus to the correct column.
     std::swap(copy[x_mod_index], copy[y_mod_index]);
-    std::swap(copy, x[x_n_rows+i]);
+    std::swap(copy, x[x_num_rows+i]);
   }
   assert(OK());
 }
@@ -186,7 +187,7 @@ PPL::Congruence_System::normalize_moduli() {
   dimension_type row = num_rows();
   if (row > 0) {
     // Calculate the LCM of all the moduli.
-    TEMP_INTEGER(lcm);
+    PPL_DIRTY_TEMP_COEFFICIENT(lcm);
     // Find last proper congruence.
     while (true) {
       lcm = operator[](--row).modulus();
@@ -197,21 +198,19 @@ PPL::Congruence_System::normalize_moduli() {
 	return;
     }
     while (row > 0) {
-      TEMP_INTEGER(modulus);
-      modulus = operator[](--row).modulus();
+      const Coefficient& modulus = operator[](--row).modulus();
       if (modulus > 0)
 	lcm_assign(lcm, lcm, modulus);
     }
 
     // Represent every row using the LCM as the modulus.
+    PPL_DIRTY_TEMP_COEFFICIENT(factor);
     dimension_type row_size = operator[](0).size();
-    for (dimension_type row = num_rows(); row-- > 0; ) {
-      TEMP_INTEGER(modulus);
-      modulus = operator[](row).modulus();
+    for (row = num_rows(); row-- > 0; ) {
+      const Coefficient& modulus = operator[](row).modulus();
       if (modulus <= 0 || modulus == lcm)
 	continue;
-      TEMP_INTEGER(factor);
-      factor = lcm / modulus;
+      exact_div_assign(factor, lcm, modulus);
       for (dimension_type col = row_size; col-- > 0; )
 	operator[](row)[col] *= factor;
       operator[](row)[row_size-1] = lcm;
@@ -225,8 +224,8 @@ PPL::Congruence_System::is_equal_to(const Congruence_System& cgs) const {
   if (num_rows() != cgs.num_rows())
     return false;
 
-  for (dimension_type row = 0; row < cgs.num_rows(); ++row)
-    for (dimension_type col = 0; col < cgs.num_columns(); ++col) {
+  for (dimension_type row = cgs.num_rows(); row-- > 0; )
+    for (dimension_type col = cgs.num_columns(); col-- > 0; ) {
       if (operator[](row)[col] == cgs[row][col])
 	continue;
       return false;
@@ -237,7 +236,7 @@ PPL::Congruence_System::is_equal_to(const Congruence_System& cgs) const {
 bool
 PPL::Congruence_System::has_linear_equalities() const {
   const Congruence_System& cgs = *this;
-  dimension_type modulus_index = cgs.num_columns() - 1;
+  const dimension_type modulus_index = cgs.num_columns() - 1;
   for (dimension_type i = cgs.num_rows(); i-- > 0; )
     if (cgs[i][modulus_index] == 0)
       return true;
@@ -247,7 +246,7 @@ PPL::Congruence_System::has_linear_equalities() const {
 void
 PPL::Congruence_System::const_iterator::skip_forward() {
   const Matrix::const_iterator csp_end = csp->end();
-  while (i != csp_end && (*this)->is_trivial_true())
+  while (i != csp_end && (*this)->is_tautological())
     ++i;
 }
 
@@ -279,7 +278,7 @@ satisfies_all_congruences(const Grid_Generator& g) const {
   assert(g.space_dimension() <= space_dimension());
 
   const Congruence_System& cgs = *this;
-  TEMP_INTEGER(sp);
+  PPL_DIRTY_TEMP_COEFFICIENT(sp);
   if (g.is_line())
     for (dimension_type i = cgs.num_rows(); i-- > 0; ) {
       const Congruence& cg = cgs[i];
@@ -312,7 +311,7 @@ PPL::Congruence_System::has_a_free_dimension() const {
   dimension_type free_dims = space_dim;
   for (dimension_type row = num_rows(); row-- > 0; ) {
     const Congruence& cg = operator[](row);
-    for (dimension_type dim = 0; dim < space_dim; ++dim)
+    for (dimension_type dim = space_dim; dim-- > 0; )
       if (free_dim[dim] && cg[dim+1] != 0) {
 	if (--free_dims == 0) {
 	  // All dimensions are constrained.
@@ -321,8 +320,8 @@ PPL::Congruence_System::has_a_free_dimension() const {
 	  // Check that there are free_dims dimensions marked free
 	  // in free_dim.
 	  dimension_type count = 0;
-	  for (dimension_type dim = 0; dim < space_dim; ++dim)
-	    count += free_dim[dim];
+	  for (dimension_type i = space_dim; i-- > 0; )
+	    count += free_dim[i];
 	  assert(count == free_dims);
 #endif
 	  return true;
@@ -345,8 +344,8 @@ affine_preimage(dimension_type v,
   assert(expr.space_dimension() <= space_dimension());
   assert(denominator > 0);
 
-  const dimension_type n_columns = num_columns();
-  const dimension_type n_rows = num_rows();
+  const dimension_type num_columns = this->num_columns();
+  const dimension_type num_rows = this->num_rows();
   const dimension_type expr_size = expr.size();
   const bool not_invertible = (v >= expr_size || expr[v] == 0);
   Congruence_System& x = *this;
@@ -354,7 +353,7 @@ affine_preimage(dimension_type v,
   if (denominator == 1)
     // Optimized computation only considering columns having indexes <
     // expr_size.
-    for (dimension_type i = n_rows; i-- > 0; ) {
+    for (dimension_type i = num_rows; i-- > 0; ) {
       Congruence& row = x[i];
       Coefficient& row_v = row[v];
       if (row_v != 0) {
@@ -369,11 +368,11 @@ affine_preimage(dimension_type v,
       }
     }
   else
-    for (dimension_type i = n_rows; i-- > 0; ) {
+    for (dimension_type i = num_rows; i-- > 0; ) {
       Congruence& row = x[i];
       Coefficient& row_v = row[v];
       if (row_v != 0) {
-	for (dimension_type j = n_columns; j-- > 0; )
+	for (dimension_type j = num_columns; j-- > 0; )
 	  if (j != v) {
 	    Coefficient& row_j = row[j];
 	    row_j *= denominator;
@@ -400,30 +399,47 @@ PPL::Congruence_System::ascii_dump(std::ostream& s) const {
       x[i].ascii_dump(s);
 }
 
-PPL_OUTPUT_DEFINITIONS(Congruence_System);
+PPL_OUTPUT_DEFINITIONS(Congruence_System)
 
 bool
 PPL::Congruence_System::ascii_load(std::istream& s) {
   std::string str;
-  dimension_type nrows;
-  dimension_type ncols;
-  if (!(s >> nrows))
+  dimension_type num_rows;
+  dimension_type num_columns;
+  if (!(s >> num_rows))
     return false;
-  if (!(s >> str))
+  if (!(s >> str) || str != "x")
     return false;
-  if (!(s >> ncols))
+  if (!(s >> num_columns))
     return false;
-  resize_no_copy(nrows, ncols);
+  resize_no_copy(num_rows, num_columns);
 
   Congruence_System& x = *this;
   for (dimension_type i = 0; i < x.num_rows(); ++i)
-    x[i].ascii_load(s);
+    if (!x[i].ascii_load(s))
+      return false;
 
-  // Check for well-formedness.
+  // Check invariants.
   assert(OK());
   return true;
 }
 
+const PPL::Congruence_System* PPL::Congruence_System::zero_dim_empty_p = 0;
+
+void
+PPL::Congruence_System::initialize() {
+  assert(zero_dim_empty_p == 0);
+  zero_dim_empty_p
+    = new Congruence_System(Congruence::zero_dim_false());
+}
+
+void
+PPL::Congruence_System::finalize() {
+  assert(zero_dim_empty_p != 0);
+  delete zero_dim_empty_p;
+  zero_dim_empty_p = 0;
+}
+
 bool
 PPL::Congruence_System::OK() const {
   // A Congruence_System must be a valid Matrix.
@@ -503,7 +519,7 @@ PPL::Congruence_System::add_unit_rows_and_columns(dimension_type dims) {
 
   col += dims - 1;
   // Set the diagonal element of each added row.
-  for (dimension_type row = 0; row < dims; ++row)
+  for (dimension_type row = dims; row-- > 0; )
     const_cast<Coefficient&>(operator[](row)[col - row]) = 1;
 }
 
@@ -515,11 +531,6 @@ PPL::Congruence_System::concatenate(const Congruence_System& const_cgs) {
   dimension_type added_rows = cgs.num_rows();
   dimension_type added_columns = cgs.space_dimension();
 
-  if (added_rows == 0) {
-    increase_space_dimension(space_dimension() + added_columns);
-    return;
-  }
-
   dimension_type old_num_rows = num_rows();
   dimension_type old_modi = num_columns() - 1;
   dimension_type old_space_dim = space_dimension();
@@ -531,7 +542,7 @@ PPL::Congruence_System::concatenate(const Congruence_System& const_cgs) {
   dimension_type modi = num_columns() - 1;
 
   // Swap the modulus and the new last column, in the old rows.
-  for (dimension_type i = 0; i < old_num_rows; ++i) {
+  for (dimension_type i = old_num_rows; i-- > 0; ) {
     Congruence& cg = operator[](i);
     std::swap(cg[old_modi], cg[modi]);
   }
@@ -544,7 +555,28 @@ PPL::Congruence_System::concatenate(const Congruence_System& const_cgs) {
     // The inhomogeneous term is moved to the same column.
     std::swap(cg_new[0], cg_old[0]);
     // All homogeneous terms are shifted by `space_dim' columns.
-    for (dimension_type j = 1; j < cgs_num_columns; ++j)
+    for (dimension_type j = cgs_num_columns; j-- > 1; )
       std::swap(cg_old[j], cg_new[old_space_dim + j]);
   }
 }
+
+void
+PPL::Congruence_System
+::remove_higher_space_dimensions(const dimension_type new_dimension) {
+  dimension_type space_dim = space_dimension();
+
+  assert(new_dimension <= space_dim);
+
+  // The removal of no dimensions from any system is a no-op.  Note
+  // that this case also captures the only legal removal of dimensions
+  // from a system in a 0-dim space.
+  if (new_dimension == space_dim)
+    return;
+
+  // Swap the modulus column into the column that will become the last
+  // column.
+  swap_columns(new_dimension + 1, space_dim + 1);
+
+  remove_trailing_columns(space_dim - new_dimension);
+  assert(OK());
+}
