@@ -1,11 +1,11 @@
 /* Constraint_System class implementation (non-inline functions).
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -20,12 +20,14 @@ Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 For the most up-to-date information see the Parma Polyhedra Library
 site: http://www.cs.unipr.it/ppl/ . */
 
-#include <config.h>
+#include <ppl-config.h>
 
 #include "Constraint_System.defs.hh"
 #include "Constraint_System.inlines.hh"
 #include "Generator.defs.hh"
 #include "Scalar_Products.defs.hh"
+#include "Congruence_System.defs.hh"
+#include "Congruence_System.inlines.hh"
 #include <cassert>
 #include <string>
 #include <vector>
@@ -34,6 +36,15 @@ site: http://www.cs.unipr.it/ppl/ . */
 
 namespace PPL = Parma_Polyhedra_Library;
 
+PPL::Constraint_System::Constraint_System(const Congruence_System& cgs)
+  : Linear_System(NECESSARILY_CLOSED, 0, cgs.space_dimension() + 1) {
+  for (Congruence_System::const_iterator i = cgs.begin(),
+	 cgs_end = cgs.end(); i != cgs_end; ++i)
+    if (i->is_equality())
+      // TODO: Consider adding a recycling_insert to save the extra copy here.
+      insert(Constraint(*i));
+}
+
 bool
 PPL::Constraint_System::
 adjust_topology_and_space_dimension(const Topology new_topology,
@@ -87,7 +98,7 @@ adjust_topology_and_space_dimension(const Topology new_topology,
     return true;
   }
 
-  // Here `num_rows() > 0'.
+  // Here the constraint system is not empty.
   if (cols_to_be_added > 0)
     if (old_topology != new_topology)
       if (new_topology == NECESSARILY_CLOSED) {
@@ -172,7 +183,7 @@ adjust_topology_and_space_dimension(const Topology new_topology,
     }
   else
     // Here `cols_to_be_added == 0'.
-    if (old_topology != new_topology)
+    if (old_topology != new_topology) {
       if (new_topology == NECESSARILY_CLOSED) {
 	// A NOT_NECESSARILY_CLOSED constraint system
 	// can be converted to a NECESSARILY_CLOSED one
@@ -188,6 +199,7 @@ adjust_topology_and_space_dimension(const Topology new_topology,
 	add_zero_columns(1);
 	set_not_necessarily_closed();
       }
+    }
   // We successfully adjusted space dimensions and topology.
   assert(OK());
   return true;
@@ -485,7 +497,7 @@ PPL::Constraint_System::ascii_dump(std::ostream& s) const {
   }
 }
 
-PPL_OUTPUT_DEFINITIONS(Constraint_System);
+PPL_OUTPUT_DEFINITIONS(Constraint_System)
 
 bool
 PPL::Constraint_System::ascii_load(std::istream& s) {
@@ -506,7 +518,7 @@ PPL::Constraint_System::ascii_load(std::istream& s) {
   dimension_type ncols;
   if (!(s >> nrows))
     return false;
-  if (!(s >> str))
+  if (!(s >> str) || str != "x")
     return false;
   if (!(s >> ncols))
       return false;
@@ -532,8 +544,10 @@ PPL::Constraint_System::ascii_load(std::istream& s) {
       return false;
     if (str == "=")
       x[i].set_is_equality();
-    else
+    else if (str == ">=" || str == ">")
       x[i].set_is_inequality();
+    else
+      return false;
 
     // Checking for equality of actual and declared types.
     switch (x[i].type()) {
@@ -553,11 +567,27 @@ PPL::Constraint_System::ascii_load(std::istream& s) {
     // Reaching this point means that the input was illegal.
     return false;
   }
-  // Check for well-formedness.
+  // Check invariants.
   assert(OK());
   return true;
 }
 
+const PPL::Constraint_System* PPL::Constraint_System::zero_dim_empty_p = 0;
+
+void
+PPL::Constraint_System::initialize() {
+  assert(zero_dim_empty_p == 0);
+  zero_dim_empty_p
+    = new Constraint_System(Constraint::zero_dim_false());
+}
+
+void
+PPL::Constraint_System::finalize() {
+  assert(zero_dim_empty_p != 0);
+  delete zero_dim_empty_p;
+  zero_dim_empty_p = 0;
+}
+
 bool
 PPL::Constraint_System::OK() const {
   // A Constraint_System must be a valid Linear_System; do not check for
