@@ -1,11 +1,11 @@
 /* Matrix class implementation (non-inline functions).
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -20,7 +20,7 @@ Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 For the most up-to-date information see the Parma Polyhedra Library
 site: http://www.cs.unipr.it/ppl/ . */
 
-#include <config.h>
+#include <ppl-config.h>
 
 #include "Matrix.defs.hh"
 #include "Row.defs.hh"
@@ -293,7 +293,7 @@ PPL::Matrix::ascii_dump(std::ostream& s) const {
     x[i].ascii_dump(s);
 }
 
-PPL_OUTPUT_DEFINITIONS_ASCII_ONLY(Matrix);
+PPL_OUTPUT_DEFINITIONS_ASCII_ONLY(Matrix)
 
 bool
 PPL::Matrix::ascii_load(std::istream& s) {
@@ -303,7 +303,7 @@ PPL::Matrix::ascii_load(std::istream& s) {
   dimension_type x_num_cols;
   if (!(s >> x_num_rows))
     return false;
-  if (!(s >> str) || (str.compare("x") != 0))
+  if (!(s >> str) || str != "x")
     return false;
   if (!(s >> x_num_cols))
     return false;
@@ -314,7 +314,7 @@ PPL::Matrix::ascii_load(std::istream& s) {
     if (!x[row].ascii_load(s))
       return false;
 
-  // Check for well-formedness.
+  // Check invariants.
   assert(OK());
   return true;
 }
@@ -339,7 +339,7 @@ PPL::Matrix::remove_trailing_columns(const dimension_type n) {
 
 void
 PPL::Matrix::permute_columns(const std::vector<dimension_type>& cycles) {
-  TEMP_INTEGER(tmp);
+  PPL_DIRTY_TEMP_COEFFICIENT(tmp);
   const dimension_type n = cycles.size();
   assert(cycles[n - 1] == 0);
   for (dimension_type k = num_rows(); k-- > 0; ) {
