@@ -1,11 +1,11 @@
 /* Test BD_Shape::relation_with().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -28,13 +28,13 @@ bool
 test01() {
   Variable A(0);
 
-  TBD_Shape bd(2, EMPTY);
+  TBD_Shape bds(2, EMPTY);
 
-  Poly_Con_Relation rel = bd.relation_with(A >= 0);
+  Poly_Con_Relation rel = bds.relation_with(A >= 0);
 
-  print_constraints(bd, "--- bd ---");
+  print_constraints(bds, "*** bds ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(A >= 0) == " << rel << endl;
+  nout << "bds.relation_with(A >= 0) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::saturates()
     && Poly_Con_Relation::is_included()
@@ -48,16 +48,16 @@ test02() {
   // Variable x(0);
   Variable y(1);
 
-  TBD_Shape bd(2);
-  bd.add_constraint(y <= -1);
+  TBD_Shape bds(2);
+  bds.add_constraint(y <= -1);
 
   Constraint c(y >= 0);
-  Poly_Con_Relation rel = bd.relation_with(c);
+  Poly_Con_Relation rel = bds.relation_with(c);
 
-  print_constraints(bd, "--- bd ---");
-  print_constraint(c, "--- c ---");
+  print_constraints(bds, "*** bds ***");
+  print_constraint(c, "*** c ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(c) == " << rel << endl;
+  nout << "bds.relation_with(c) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::is_disjoint();
 
@@ -70,16 +70,16 @@ test03() {
   Variable y(1);
   // Variable z(2);
 
-  TBD_Shape bd(3);
-  bd.add_constraint(y <= 1);
+  TBD_Shape bds(3);
+  bds.add_constraint(y <= 1);
 
   Constraint c(y >= 0);
-  Poly_Con_Relation rel = bd.relation_with(c);
+  Poly_Con_Relation rel = bds.relation_with(c);
 
-  print_constraints(bd, "--- bd ---");
-  print_constraint(c, "--- c ---");
+  print_constraints(bds, "*** bds ***");
+  print_constraint(c, "*** c ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(c) == " << rel << endl;
+  nout << "bds.relation_with(c) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::strictly_intersects();
 
@@ -92,16 +92,16 @@ test04() {
   // Variable y(1);
   Variable z(2);
 
-  TBD_Shape bd(3);
-  bd.add_constraint(z >= 1);
+  TBD_Shape bds(3);
+  bds.add_constraint(z >= 1);
 
   Constraint c(z >= 0);
-  Poly_Con_Relation rel = bd.relation_with(c);
+  Poly_Con_Relation rel = bds.relation_with(c);
 
-  print_constraints(bd, "--- bd ---");
-  print_constraint(c, "--- c ---");
+  print_constraints(bds, "*** bds ***");
+  print_constraint(c, "*** c ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(c) == " << rel << endl;
+  nout << "bds.relation_with(c) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::is_included();
 
@@ -113,16 +113,16 @@ test05() {
   Variable x(0);
   // Variable y(1);
 
-  TBD_Shape bd(2);
-  bd.add_constraint(x == 1);
+  TBD_Shape bds(2);
+  bds.add_constraint(x == 1);
 
   Constraint c(x >= 1);
-  Poly_Con_Relation rel = bd.relation_with(c);
+  Poly_Con_Relation rel = bds.relation_with(c);
 
-  print_constraints(bd, "--- bd ---");
-  print_constraint(c, "--- c ---");
+  print_constraints(bds, "*** bds ***");
+  print_constraint(c, "*** c ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(c) == " << rel << endl;
+  nout << "bds.relation_with(c) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::saturates()
     && Poly_Con_Relation::is_included();
@@ -136,18 +136,18 @@ test06() {
   Variable y(1);
   Variable z(2);
 
-  TBD_Shape bd(3);
-  bd.add_constraint(x == 1);
-  bd.add_constraint(y <= 0);
-  bd.add_constraint(z >= 2);
+  TBD_Shape bds(3);
+  bds.add_constraint(x == 1);
+  bds.add_constraint(y <= 0);
+  bds.add_constraint(z >= 2);
 
   Constraint c(x == 1);
-  Poly_Con_Relation rel = bd.relation_with(c);
+  Poly_Con_Relation rel = bds.relation_with(c);
 
-  print_constraints(bd, "--- bd ---");
-  print_constraint(c, "--- c ---");
+  print_constraints(bds, "*** bds ***");
+  print_constraint(c, "*** c ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(c) == " << rel << endl;
+  nout << "bds.relation_with(c) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::saturates()
     && Poly_Con_Relation::is_included();
@@ -161,18 +161,18 @@ test07() {
   Variable y(1);
   Variable z(2);
 
-  TBD_Shape bd(3);
-  bd.add_constraint(x >= 3);
-  bd.add_constraint(y <= 0);
-  bd.add_constraint(z >= 2);
+  TBD_Shape bds(3);
+  bds.add_constraint(x >= 3);
+  bds.add_constraint(y <= 0);
+  bds.add_constraint(z >= 2);
 
   Constraint c(x == 2);
-  Poly_Con_Relation rel = bd.relation_with(c);
+  Poly_Con_Relation rel = bds.relation_with(c);
 
-  print_constraints(bd, "--- bd ---");
-  print_constraint(c, "--- c ---");
+  print_constraints(bds, "*** bds ***");
+  print_constraint(c, "*** c ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(c) == " << rel << endl;
+  nout << "bds.relation_with(c) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::is_disjoint();
 
@@ -185,18 +185,18 @@ test08() {
   Variable y(1);
   Variable z(2);
 
-  TBD_Shape bd(3);
-  bd.add_constraint(x <= 3);
-  bd.add_constraint(y <= 0);
-  bd.add_constraint(z >= 2);
+  TBD_Shape bds(3);
+  bds.add_constraint(x <= 3);
+  bds.add_constraint(y <= 0);
+  bds.add_constraint(z >= 2);
 
   Constraint c(x == 2);
-  Poly_Con_Relation rel = bd.relation_with(c);
+  Poly_Con_Relation rel = bds.relation_with(c);
 
-  print_constraints(bd, "--- bd ---");
-  print_constraint(c, "--- c ---");
+  print_constraints(bds, "*** bds ***");
+  print_constraint(c, "*** c ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(c) == " << rel << endl;
+  nout << "bds.relation_with(c) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::strictly_intersects();
 
@@ -209,18 +209,18 @@ test09() {
   Variable y(1);
   Variable z(2);
 
-  TBD_Shape bd(3);
-  bd.add_constraint(x <= 3);
-  bd.add_constraint(y <= 0);
-  bd.add_constraint(z >= 2);
+  TBD_Shape bds(3);
+  bds.add_constraint(x <= 3);
+  bds.add_constraint(y <= 0);
+  bds.add_constraint(z >= 2);
 
   Constraint c(-x >= 2);
-  Poly_Con_Relation rel = bd.relation_with(c);
+  Poly_Con_Relation rel = bds.relation_with(c);
 
-  print_constraints(bd, "--- bd ---");
-  print_constraint(c, "--- c ---");
+  print_constraints(bds, "*** bds ***");
+  print_constraint(c, "*** c ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(c) == " << rel << endl;
+  nout << "bds.relation_with(c) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::strictly_intersects();
 
@@ -230,12 +230,12 @@ test09() {
 bool
 test10() {
   // The zero-dim universe BDS.
-  TBD_Shape bd(0);
-  Poly_Con_Relation rel = bd.relation_with(Linear_Expression(0) >= 0);
+  TBD_Shape bds(0);
+  Poly_Con_Relation rel = bds.relation_with(Linear_Expression(0) >= 0);
 
-  print_constraints(bd, "--- bd ---");
+  print_constraints(bds, "*** bds ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(0 >= 0) == " << rel << endl;
+  nout << "bds.relation_with(0 >= 0) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::is_included()
     && Poly_Con_Relation::saturates();
@@ -246,12 +246,12 @@ test10() {
 bool
 test11() {
   // The zero-dim universe BDS.
-  TBD_Shape bd(0);
-  Poly_Con_Relation rel = bd.relation_with(Linear_Expression(0) >= 1);
+  TBD_Shape bds(0);
+  Poly_Con_Relation rel = bds.relation_with(Linear_Expression(0) >= 1);
 
-  print_constraints(bd, "--- bd ---");
+  print_constraints(bds, "*** bds ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(0 >= 1) == " << rel << endl;
+  nout << "bds.relation_with(0 >= 1) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::is_disjoint();
 
@@ -261,12 +261,12 @@ test11() {
 bool
 test12() {
   // The zero-dim universe BDS.
-  TBD_Shape bd;
-  Poly_Con_Relation rel = bd.relation_with(Linear_Expression(1) >= 0);
+  TBD_Shape bds;
+  Poly_Con_Relation rel = bds.relation_with(Linear_Expression(1) >= 0);
 
-  print_constraints(bd, "--- bd ---");
+  print_constraints(bds, "*** bds ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(1 >= 0) == " << rel << endl;
+  nout << "bds.relation_with(1 >= 0) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::is_included();
 
@@ -278,16 +278,16 @@ test13() {
   Variable x(0);
   // Variable y(1);
 
-  TBD_Shape bd(2);
-  bd.add_constraint(x == 1);
+  TBD_Shape bds(2);
+  bds.add_constraint(x == 1);
 
   Constraint c(x > 1);
-  Poly_Con_Relation rel = bd.relation_with(c);
+  Poly_Con_Relation rel = bds.relation_with(c);
 
-  print_constraints(bd, "--- bd ---");
-  print_constraint(c, "--- c ---");
+  print_constraints(bds, "*** bds ***");
+  print_constraint(c, "*** c ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(c) == " << rel << endl;
+  nout << "bds.relation_with(c) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::saturates()
     && Poly_Con_Relation::is_disjoint();
@@ -301,18 +301,18 @@ test14() {
   Variable y(1);
   Variable z(2);
 
-  TBD_Shape bd(3);
-  bd.add_constraint(x == 1);
-  bd.add_constraint(y <= 0);
-  bd.add_constraint(z >= 2);
+  TBD_Shape bds(3);
+  bds.add_constraint(x == 1);
+  bds.add_constraint(y <= 0);
+  bds.add_constraint(z >= 2);
 
   Constraint c(x > 1);
-  Poly_Con_Relation rel = bd.relation_with(c);
+  Poly_Con_Relation rel = bds.relation_with(c);
 
-  print_constraints(bd, "--- bd ---");
-  print_constraint(c, "--- c ---");
+  print_constraints(bds, "*** bds ***");
+  print_constraint(c, "*** c ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(c) == " << rel << endl;
+  nout << "bds.relation_with(c) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::saturates()
     && Poly_Con_Relation::is_disjoint();
@@ -325,15 +325,15 @@ test15() {
   Variable x(0);
   Variable y(1);
 
-  TBD_Shape bd(2);
-  bd.add_constraint(x == 0);
-  bd.add_constraint(y >= 1);
+  TBD_Shape bds(2);
+  bds.add_constraint(x == 0);
+  bds.add_constraint(y >= 1);
 
-  Poly_Con_Relation rel = bd.relation_with(-y >= -1);
+  Poly_Con_Relation rel = bds.relation_with(-y >= -1);
 
-  print_constraints(bd, "--- bd ---");
+  print_constraints(bds, "*** bds ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(-y >= -1) == " << rel << endl;
+  nout << "bds.relation_with(-y >= -1) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::strictly_intersects();
 
@@ -346,17 +346,17 @@ test16() {
   Variable y(1);
   Variable z(2);
 
-  TBD_Shape bd(3);
+  TBD_Shape bds(3);
 
-  bd.add_constraint(x - y <= 2);
-  bd.add_constraint(x - z >= -1);
-  bd.add_constraint(y <= 3);
+  bds.add_constraint(x - y <= 2);
+  bds.add_constraint(x - z >= -1);
+  bds.add_constraint(y <= 3);
 
-  Poly_Con_Relation rel = bd.relation_with(y > 3);
+  Poly_Con_Relation rel = bds.relation_with(y > 3);
 
-  print_constraints(bd, "--- bd ---");
+  print_constraints(bds, "*** bds ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(y > 3) == " << rel << endl;
+  nout << "bds.relation_with(y > 3) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::is_disjoint();
 
@@ -369,17 +369,17 @@ test17() {
   Variable y(1);
   Variable z(2);
 
-  TBD_Shape bd(3);
+  TBD_Shape bds(3);
 
-  bd.add_constraint(x - y <= 2);
-  bd.add_constraint(x - z >= -1);
-  bd.add_constraint(y <= 3);
+  bds.add_constraint(x - y <= 2);
+  bds.add_constraint(x - z >= -1);
+  bds.add_constraint(y <= 3);
 
-  Poly_Con_Relation rel = bd.relation_with(-y >= -4);
+  Poly_Con_Relation rel = bds.relation_with(-y >= -4);
 
-  print_constraints(bd, "--- bd ---");
+  print_constraints(bds, "*** bds ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(1 >= 0) == " << rel << endl;
+  nout << "bds.relation_with(1 >= 0) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::is_included();
 
@@ -390,15 +390,15 @@ bool
 test18() {
   Variable A(0);
 
-  TBD_Shape bd(1);
-  bd.add_constraint(A <= 0);
-  bd.add_constraint(A >= -2);
+  TBD_Shape bds(1);
+  bds.add_constraint(A <= 0);
+  bds.add_constraint(A >= -2);
 
-  Poly_Con_Relation rel = bd.relation_with(Linear_Expression(0) >= -1);
+  Poly_Con_Relation rel = bds.relation_with(Linear_Expression(0) >= -1);
 
-  print_constraints(bd, "--- bd ---");
+  print_constraints(bds, "*** bds ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(0 >= -1) == " << rel << endl;
+  nout << "bds.relation_with(0 >= -1) == " << rel << endl;
 
   Poly_Con_Relation known_result = Poly_Con_Relation::is_included();
 
@@ -410,15 +410,15 @@ test19() {
   // We verify that a generator is not subsumed by an empty BDS.
   Variable x(0);
 
-  TBD_Shape bd(2, EMPTY);
+  TBD_Shape bds(2, EMPTY);
 
   Generator g = point(x);
-  Poly_Gen_Relation rel = bd.relation_with(g);
+  Poly_Gen_Relation rel = bds.relation_with(g);
 
-  print_constraints(bd, "--- bd ---");
-  print_generator(g, "--- g ---");
+  print_constraints(bds, "*** bds ***");
+  print_generator(g, "*** g ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(v(A)) == " << rel << endl;
+  nout << "bds.relation_with(v(A)) == " << rel << endl;
 
   Poly_Gen_Relation known_result = Poly_Gen_Relation::nothing();
 
@@ -429,15 +429,15 @@ bool
 test20() {
   // We verify that a zero-dimensional generator is subsumed
   // by a zero-dimensional, universal BDS.
-  TBD_Shape bd;
+  TBD_Shape bds;
 
   Generator g = point();
-  Poly_Gen_Relation rel = bd.relation_with(g);
+  Poly_Gen_Relation rel = bds.relation_with(g);
 
-  print_constraints(bd, "--- bd ---");
-  print_generator(g, "--- g ---");
+  print_constraints(bds, "*** bds ***");
+  print_generator(g, "*** g ***");
   using namespace IO_Operators;
-  nout << "bd.relation_with(v()) == " << rel << endl;
+  nout << "bds.relation_with(v()) == " << rel << endl;
 
   Poly_Gen_Relation known_result = Poly_Gen_Relation::subsumes();
 
