@@ -1,11 +1,11 @@
 /* Test methods which add a single congruence to a grid.
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -39,8 +39,7 @@ test01() {
 
   gr.add_congruence((A + B %= 0) / 6);
 
-  print_congruences(gr,
-		    "*** gr.add_congruence((A + B %= 0) / 6) ***");
+  print_congruences(gr, "*** gr.add_congruence((A + B %= 0) / 6) ***");
 
   gr.add_congruence_and_minimize((A + B %= 0) / 3);
 
@@ -50,7 +49,7 @@ test01() {
   bool ok = (gr == known_gr) ;
 
   print_congruences(gr,
-	"*** gr.add_congruence_and_minimize((A + B %= 0) / 3) ***");
+		    "*** gr.add_congruence_and_minimize((A + B %= 0) / 3) ***");
 
   return ok;
 }
@@ -89,10 +88,10 @@ test03() {
   gr.add_congruence((A %= 0) / 7);
 
   Grid known_gr(3, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(parameter(7*A));
-  known_gr.add_generator(parameter(7*B));
-  known_gr.add_generator(grid_line(C));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(parameter(7*A));
+  known_gr.add_grid_generator(parameter(7*B));
+  known_gr.add_grid_generator(grid_line(C));
 
   bool ok = (gr == known_gr);
 
@@ -113,10 +112,10 @@ test04() {
   gr.add_congruence_and_minimize((A %= 0) / 7);
 
   Grid known_gr(3, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(parameter(7*A));
-  known_gr.add_generator(parameter(7*B));
-  known_gr.add_generator(grid_line(C));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(parameter(7*A));
+  known_gr.add_grid_generator(parameter(7*B));
+  known_gr.add_grid_generator(grid_line(C));
 
   bool ok = (gr == known_gr);
 
@@ -125,6 +124,26 @@ test04() {
   return ok;
 }
 
+// Space dimension exception.
+static bool
+test05() {
+  Variable A(0);
+  Variable C(2);
+
+  Grid gr(2);
+
+  try {
+    gr.add_congruence(A + C %= 0);
+  }
+  catch (const std::invalid_argument& e) {
+    nout << "invalid_argument: " << e.what() << endl;
+    return true;
+  }
+  catch (...) {
+  }
+  return false;
+}
+
 } // namespace
 
 BEGIN_MAIN
@@ -132,4 +151,5 @@ BEGIN_MAIN
   DO_TEST(test02);
   DO_TEST(test03);
   DO_TEST(test04);
+  DO_TEST(test05);
 END_MAIN
