@@ -1,11 +1,11 @@
 /* Test Grid::affine_image().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -44,14 +44,13 @@ test01() {
   gr.affine_image(A, 2*A, 5);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_point(2*A, 15));
-  known_gr.add_generator(grid_point(5*B, 10));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_point(2*A, 15));
+  known_gr.add_grid_generator(grid_point(5*B, 10));
 
   bool ok = (gr == known_gr);
 
-  print_generators(gr,
-        "*** gr.affine_image(A, 2*A, 5) ***");
+  print_generators(gr, "*** gr.affine_image(A, 2*A, 5) ***");
 
   return ok;
 }
@@ -63,19 +62,18 @@ test02() {
   Variable B(1);
 
   Grid gr(2, EMPTY);
-  gr.add_generator(grid_point(A));
+  gr.add_grid_generator(grid_point(A));
 
   print_generators(gr, "*** gr ***");
 
   gr.affine_image(A, B + 2, -3);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point(-2*A, 3));
+  known_gr.add_grid_generator(grid_point(-2*A, 3));
 
   bool ok = (gr == known_gr);
 
-  print_generators(gr,
-        "*** gr.affine_image(A, B + 2, -3) ***");
+  print_generators(gr, "*** gr.affine_image(A, B + 2, -3) ***");
 
   return ok;
 }
@@ -96,8 +94,7 @@ test03() {
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.affine_image(A, 2*A + B + 1) ***");
+  print_congruences(gr, "*** gr.affine_image(A, 2*A + B + 1) ***");
 
   return ok;
 }
@@ -123,8 +120,7 @@ test04() {
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.affine_image(A, A + 3) ***");
+  print_congruences(gr, "*** gr.affine_image(A, A + 3) ***");
 
   return ok;
 }
@@ -150,8 +146,7 @@ test05() {
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.affine_image(A, A + B) ***");
+  print_congruences(gr, "*** gr.affine_image(A, A + B) ***");
 
   return ok;
 }
@@ -172,13 +167,12 @@ test06() {
   gr.affine_image(A, B);
 
   Grid known_gr(2);
-  known_gr.add_congruence(A - B == 0);
+  known_gr.add_congruence((A - B == 0) / 0);
   known_gr.add_congruence((A %= 0) / 2);
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.affine_image(A, B) ***");
+  print_congruences(gr, "*** gr.affine_image(A, B) ***");
 
   return ok;
 }
@@ -199,11 +193,11 @@ test07() {
   }
   catch (const std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl;
+    return true;
   }
   catch (...) {
-    return false;
   }
-  return true;
+  return false;
 }
 
 // Expression of a greater space dimension than the grid.
@@ -223,11 +217,11 @@ test08() {
   }
   catch (const std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl;
+    return true;
   }
   catch (...) {
-    return false;
   }
-  return true;
+  return false;
 }
 
 // Variable of a greater space dimension than the grid.
@@ -247,11 +241,11 @@ test09() {
   }
   catch (const std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl;
+    return true;
   }
   catch (...) {
-    return false;
   }
-  return true;
+  return false;
 }
 
 // Based on an example in a paper by Muller-Olm and Seidl in SAS 2005
@@ -263,7 +257,7 @@ test10() {
   Variable D(3);
 
   Grid gr(2, EMPTY);
-  gr.add_generator(grid_point(2*A + 0*B));
+  gr.add_grid_generator(grid_point(2*A + 0*B));
 
   print_congruences(gr, "*** gr ***");
 
@@ -271,8 +265,8 @@ test10() {
 
   Grid gr1 = gr;  // second grid - initial state
 
-  gr1.generalized_affine_image(B, 18*A + B, 1, 0);
-  gr1.generalized_affine_image(A, 15*A, 1, 0);
+  gr1.generalized_affine_image(B, EQUAL, 18*A + B, 1, 0);
+  gr1.generalized_affine_image(A, EQUAL, 15*A, 1, 0);
                   // second grid - 1 pass through procedure
 
   Grid gr2 = gr;  // third grid - initial state
@@ -281,12 +275,11 @@ test10() {
   gr2.affine_image(A, 225*A);
                   // third grid - 2 passes through procedure
 
-  gr.join_assign(gr1); // join of gr0 and gr1
+  gr.upper_bound_assign(gr1); // join of gr0 and gr1
 
-  print_congruences(gr,
-        "*** gr.join_assign(gr1) ***");
+  print_congruences(gr, "*** gr.upper_bound_assign(gr1) ***");
 
-  gr.join_assign(gr2); // join of gr0, gr1 and gr2
+  gr.upper_bound_assign(gr2); // join of gr0, gr1 and gr2
 
   Grid known_gr(2);
 
@@ -295,8 +288,93 @@ test10() {
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.join_assign(gr2) ***");
+  print_congruences(gr, "*** gr.upper_bound_assign(gr2) ***");
+
+  return ok;
+}
+
+// Example from Muller-Olm and Seidl SAS 2005 paper
+bool
+test11() {
+
+  Variable A(0);
+  Variable B(1);
+
+  Grid_Generator_System ggs;
+  ggs.insert(grid_point(A + 0*B));
+
+  Grid gr1(ggs);
+  Grid gr(2, EMPTY);
+
+  for(int j = 0; j < 4; j++) {
+    gr.add_grid_generators_and_minimize(ggs);
+
+    for(int i = 0; i < j; i++) {
+      gr.affine_image(A, 3*A);
+      gr.affine_image(B, B + A);
+    }
+    for(int i = 0; i < j; i++) {
+      gr.affine_image(A, 5*A);
+      gr.affine_image(B, B + A);
+    }
+    gr1.upper_bound_assign(gr);
+  }
+
+  gr.add_grid_generators_and_minimize(ggs);
+
+  bool ok = (gr == gr1);
+
+  print_congruences(gr1, "*** gr1 ***");
+  print_generators(gr1, "*** gr1 ***");
+  print_congruences(gr, "*** gr ***");
+  print_generators(gr, "*** gr ***");
+
+  return ok;
+}
+
+// Example from Muller-Olm and Seidl ESOP 2005 paper
+bool
+test12() {
+
+  Variable A(0);
+  Variable B(1);
+
+  Coefficient* tem1 = new Coefficient("7654321");
+  Coefficient* tem2 = new Coefficient("69246289");
+  Coefficient* tem3 = new Coefficient("4294967296");
+
+  Grid_Generator_System ggs;
+  ggs.insert(grid_point(A));
+  ggs.insert(parameter(*tem3*A));
+  ggs.insert(parameter(*tem3*B));
+
+  Grid gr1(ggs);
+  Grid gr(2, EMPTY);
+
+  for(int j = 0; j < 3; j++) {
+    gr.add_grid_generators_and_minimize(ggs);
+
+    for(int i = 0; i < j; i++) {
+      gr.affine_image(A, *tem1*A);
+      gr.affine_image(B, B + A);
+    }
+    for(int i = 0; i < j; i++) {
+      gr.affine_image(A, *tem2*A);
+      gr.affine_image(B, B + A);
+    }
+    gr1.upper_bound_assign(gr);
+  }
+
+  gr.add_grid_generators_and_minimize(ggs);
+
+  delete tem1; delete tem2; delete tem3;
+
+  bool ok = (gr == gr1);
+
+  print_congruences(gr1, "*** gr1 ***");
+  print_generators(gr1, "*** gr1 ***");
+  print_congruences(gr, "*** gr ***");
+  print_generators(gr, "*** gr ***");
 
   return ok;
 }
@@ -314,4 +392,6 @@ BEGIN_MAIN
   DO_TEST(test08);
   DO_TEST(test09);
   DO_TEST_F16A(test10);
+  DO_TEST_F16(test11);
+  DO_TEST_F64(test12);
 END_MAIN
