@@ -1,11 +1,11 @@
 /* Test Grid::concatenate_assign().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -180,8 +180,8 @@ test05() {
 
   Congruence_System known_cgs;
   known_cgs.insert((A == 1) / 0);
-  known_cgs.insert((C %= 0) / 1);
   known_cgs.insert((B == 0) / 0);
+  known_cgs.insert((C %= 0) / 1);
   known_cgs.insert((D == 0) / 0);
   known_cgs.insert((E %= 0) / 1);
 
@@ -299,7 +299,7 @@ test09() {
 
 // Space dimension exception.
 bool
-test10() {
+test11() {
   Grid gr1(7);
 
   Grid gr2(1);
@@ -310,19 +310,18 @@ test10() {
   // integrality congruence.  The presence of the integrality
   // congruence is required by the conversion.
 
-  gr2.add_space_dimensions_and_embed(Grid::max_space_dimension() - 1);
-  print_congruences(gr2, "*** gr2 ***");
+  gr2.add_space_dimensions_and_project(Grid::max_space_dimension() - 1);
 
   try {
     gr1.concatenate_assign(gr2);
   }
   catch (const std::length_error& e) {
     nout << "max_space_dimension_exceeded: " << e.what() << endl;
+    return true;
   }
   catch (...) {
-    return false;
   }
-  return true;
+  return false;
 }
 
 } // namespace
@@ -337,5 +336,5 @@ BEGIN_MAIN
   DO_TEST(test07);
   DO_TEST(test08);
   DO_TEST(test09);
-  //  DO_TEST(test10);
+  // DO_TEST(test11);
 END_MAIN
