@@ -1,11 +1,11 @@
  /* Test Grid::get_covering_box().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -28,46 +28,6 @@ namespace {
 
 #define SPACE_DIM 2
 
-bool
-operator==(const Bounding_Box& x, const Bounding_Box& y) {
-  dimension_type dimension = x.space_dimension();
-  if (dimension != y.space_dimension())
-    return false;
-
-  if (x.is_empty() && y.is_empty())
-    return true;
-
-  if (x.is_empty() || y.is_empty())
-    return false;
-
-  TEMP_INTEGER(n_x);
-  TEMP_INTEGER(n_y);
-  TEMP_INTEGER(d_x);
-  TEMP_INTEGER(d_y);
-
-  for (dimension_type i = dimension; i-- > 0; ) {
-    bool tem;
-    bool x_closed = x.get_lower_bound(i, tem, n_x, d_x);
-    bool y_closed = y.get_lower_bound(i, tem, n_y, d_y);
-    if (x_closed == y_closed) {
-      if (x_closed && (n_x != n_y || d_x != d_y))
-	return false;
-    }
-    else
-      return false;
-    x_closed = x.get_upper_bound(i, tem, n_x, d_x);
-    y_closed = y.get_upper_bound(i, tem, n_y, d_y);
-    if (x_closed == y_closed) {
-      if (x_closed && (n_x != n_y || d_x != d_y))
-	return false;
-    }
-    else
-      return false;
-  }
-
-  return true;
-}
-
 // Rectilinear grid defined by points with the origin
 // not a point of the grid or a point of the covering box..
 bool
@@ -75,20 +35,20 @@ test01() {
   Variable A(0);
   Variable B(1);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point(B));
-  gr.add_generator(grid_point(3*A + B));
-  gr.add_generator(grid_point(3*A + 3*B));
+  gr.add_grid_generator(grid_point(B));
+  gr.add_grid_generator(grid_point(3*A + B));
+  gr.add_grid_generator(grid_point(3*A + 3*B));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 3, 1);
-  known_box.raise_lower_bound(1, true, 1, 1);
-  known_box.lower_upper_bound(1, true, 3, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A >= 0);
+  known_box.add_constraint(A <= 3);
+  known_box.add_constraint(B >= 1);
+  known_box.add_constraint(B <= 3);
 
   bool ok = (box1 == known_box);
 
@@ -97,7 +57,7 @@ test01() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -114,20 +74,20 @@ test02() {
   Variable A(0);
   Variable B(1);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point(  A +   B));
-  gr.add_generator(grid_point(2*A + 3*B));
-  gr.add_generator(grid_point(  A + 4*B));
+  gr.add_grid_generator(grid_point(  A +   B));
+  gr.add_grid_generator(grid_point(2*A + 3*B));
+  gr.add_grid_generator(grid_point(  A + 4*B));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 1, 1);
-  known_box.raise_lower_bound(1, true, 0, 1);
-  known_box.lower_upper_bound(1, true, 1, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A >= 0);
+  known_box.add_constraint(A <= 1);
+  known_box.add_constraint(B >= 0);
+  known_box.add_constraint(B <= 1);
 
   bool ok = (box1 == known_box);
 
@@ -136,7 +96,7 @@ test02() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -153,20 +113,20 @@ test03() {
   Variable A(0);
   Variable B(1);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(2*A));
-  gr.add_generator(grid_point(  A + 2*B, 2));
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_point(2*A));
+  gr.add_grid_generator(grid_point(  A + 2*B, 2));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 2);
-  known_box.lower_upper_bound(0, true, 1, 2);
-  known_box.raise_lower_bound(1, true, 0, 2);
-  known_box.lower_upper_bound(1, true, 2, 2);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(2*A >= 0);
+  known_box.add_constraint(2*A <= 1);
+  known_box.add_constraint(2*B >= 0);
+  known_box.add_constraint(2*B <= 2);
 
   bool ok = (box1 == known_box);
 
@@ -175,7 +135,7 @@ test03() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -196,22 +156,20 @@ test04() {
   Variable B(1);
   Variable C(2);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_line(A + 2*B));
-  gr.add_generator(grid_point(C, 2));
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_line(A + 2*B));
+  gr.add_grid_generator(grid_point(C, 2));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 0, 1);
-  known_box.raise_lower_bound(1, true, 0, 1);
-  known_box.lower_upper_bound(1, true, 0, 1);
-  known_box.raise_lower_bound(2, true, 0, 1);
-  known_box.lower_upper_bound(2, true, 1, 2);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A == 0);
+  known_box.add_constraint(B == 0);
+  known_box.add_constraint(C >= 0);
+  known_box.add_constraint(2*C <= 1);
 
   bool ok = (box1 == known_box);
 
@@ -220,7 +178,7 @@ test04() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -234,19 +192,20 @@ test04() {
 // Universe grid.
 bool
 test05() {
-  Bounding_Box box1(SPACE_DIM);
+  Variable A(0);
+  Variable B(1);
+  Variable C(2);
+
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM);
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 0, 1);
-  known_box.raise_lower_bound(1, true, 0, 1);
-  known_box.lower_upper_bound(1, true, 0, 1);
-  known_box.raise_lower_bound(2, true, 0, 1);
-  known_box.lower_upper_bound(2, true, 0, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A == 0);
+  known_box.add_constraint(B == 0);
+  known_box.add_constraint(C == 0);
 
   bool ok = (box1 == known_box);
 
@@ -255,7 +214,7 @@ test05() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -273,17 +232,17 @@ test06() {
   Variable B(1);
   Variable C(2);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point(16*A + 6*B - 6*C, 7));
+  gr.add_grid_generator(grid_point(16*A + 6*B - 6*C, 7));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 16, 7);
-  known_box.raise_lower_bound(1, true, 6, 7);
-  known_box.raise_lower_bound(2, true, -6, 7);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(7*A >= 16);
+  known_box.add_constraint(7*B >= 6);
+  known_box.add_constraint(7*C >= -6);
 
   bool ok = (box1 == known_box);
 
@@ -292,7 +251,7 @@ test06() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -306,17 +265,21 @@ test06() {
 // Empty grid.
 bool
 test07() {
-  Bounding_Box box1(SPACE_DIM);
+  Variable A(0);
+  Variable B(1);
+  Variable C(2);
+
+  Rational_Box box1(SPACE_DIM);
   // Set bounds, to check that get_covering_box clears them.
-  box1.raise_lower_bound(0, true, 16, 7);
-  box1.raise_lower_bound(1, true, 6, 7);
-  box1.raise_lower_bound(2, true, -6, 7);
+  box1.add_constraint(7*A >= 16);
+  box1.add_constraint(7*B >= 6);
+  box1.add_constraint(7*C >= -6);
 
   Grid gr(SPACE_DIM, EMPTY);
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
+  Rational_Box known_box(SPACE_DIM);
   known_box.set_empty();
 
   bool ok = (box1 == known_box);
@@ -327,11 +290,11 @@ test07() {
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
 
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     // Set bounds, to check that get_covering_box clears them.
-    box2.raise_lower_bound(0, true, 1, 3);
-    box2.raise_lower_bound(1, true, 2, 2);
-    box2.raise_lower_bound(2, true, 3, 1);
+    box2.add_constraint(3*A >= 1);
+    box2.add_constraint(2*B >= 2);
+    box2.add_constraint(C >= 3);
 
     tem_gr.get_covering_box(box2);
 
@@ -350,24 +313,24 @@ test08() {
   Variable B(1);
   Variable C(2);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(A + B));
-  gr.add_generator(grid_point(A));
-  gr.add_generator(grid_point(2*A));
-  gr.add_generator(grid_point(C));
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_point(A + B));
+  gr.add_grid_generator(grid_point(A));
+  gr.add_grid_generator(grid_point(2*A));
+  gr.add_grid_generator(grid_point(C));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 1, 1);
-  known_box.raise_lower_bound(1, true, 0, 1);
-  known_box.lower_upper_bound(1, true, 1, 1);
-  known_box.raise_lower_bound(2, true, 0, 1);
-  known_box.lower_upper_bound(2, true, 1, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A >= 0);
+  known_box.add_constraint(A <= 1);
+  known_box.add_constraint(B >= 0);
+  known_box.add_constraint(B <= 1);
+  known_box.add_constraint(C >= 0);
+  known_box.add_constraint(C <= 1);
 
   bool ok = (box1 == known_box);
 
@@ -376,7 +339,7 @@ test08() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -394,7 +357,7 @@ test09() {
   Variable B(1);
   Variable C(2);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM);
   gr.add_congruence((A + 2*B %= 0) / 2);
@@ -402,13 +365,13 @@ test09() {
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 5, 1);
-  known_box.raise_lower_bound(1, true, 0, 1);
-  known_box.lower_upper_bound(1, true, 1, 2);
-  known_box.raise_lower_bound(2, true, 0, 1);
-  known_box.lower_upper_bound(2, true, 0, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A >= 0);
+  known_box.add_constraint(A <= 5);
+  known_box.add_constraint(B >= 0);
+  known_box.add_constraint(2*B <= 1);
+  known_box.add_constraint(C >= 0);
+  known_box.add_constraint(C <= 0);
 
   bool ok = (box1 == known_box);
 
@@ -417,7 +380,7 @@ test09() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -435,23 +398,22 @@ test10() {
   Variable B(1);
   Variable C(2);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(A));
-  gr.add_generator(grid_point(B));
-  gr.add_generator(grid_line(C));
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_point(A));
+  gr.add_grid_generator(grid_point(B));
+  gr.add_grid_generator(grid_line(C));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 1, 1);
-  known_box.raise_lower_bound(1, true, 0, 1);
-  known_box.lower_upper_bound(1, true, 1, 1);
-  known_box.raise_lower_bound(2, true, 0, 1);
-  known_box.lower_upper_bound(2, true, 0, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A >= 0);
+  known_box.add_constraint(A <= 1);
+  known_box.add_constraint(B >= 0);
+  known_box.add_constraint(B <= 1);
+  known_box.add_constraint(C == 0);
 
   bool ok = (box1 == known_box);
 
@@ -460,7 +422,7 @@ test10() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -484,26 +446,26 @@ test11() {
   Variable C(2);
   Variable D(3);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(A + 2*D));
-  gr.add_generator(grid_point(B + 4*D));
-  gr.add_generator(grid_point(C + 8*D));
-  gr.add_generator(grid_point(16*D));
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_point(A + 2*D));
+  gr.add_grid_generator(grid_point(B + 4*D));
+  gr.add_grid_generator(grid_point(C + 8*D));
+  gr.add_grid_generator(grid_point(16*D));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 1, 1);
-  known_box.raise_lower_bound(1, true, 0, 1);
-  known_box.lower_upper_bound(1, true, 1, 1);
-  known_box.raise_lower_bound(2, true, 0, 1);
-  known_box.lower_upper_bound(2, true, 1, 1);
-  known_box.raise_lower_bound(3, true, 0, 1);
-  known_box.lower_upper_bound(3, true, 2, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A >= 0);
+  known_box.add_constraint(A <= 1);
+  known_box.add_constraint(B >= 0);
+  known_box.add_constraint(B <= 1);
+  known_box.add_constraint(C >= 0);
+  known_box.add_constraint(C <= 1);
+  known_box.add_constraint(D >= 0);
+  known_box.add_constraint(D <= 2);
 
   bool ok = (box1 == known_box);
 
@@ -513,7 +475,7 @@ test11() {
   if (ok) {
 
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -533,24 +495,24 @@ test12() {
   Variable C(2);
   Variable D(3);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(A));
-  gr.add_generator(grid_point(C));
-  gr.add_generator(grid_point(D));
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_point(A));
+  gr.add_grid_generator(grid_point(C));
+  gr.add_grid_generator(grid_point(D));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 1, 1);
-  known_box.raise_lower_bound(1, true, 0, 1);
-  known_box.raise_lower_bound(2, true, 0, 1);
-  known_box.lower_upper_bound(2, true, 1, 1);
-  known_box.raise_lower_bound(3, true, 0, 1);
-  known_box.lower_upper_bound(3, true, 1, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A >= 0);
+  known_box.add_constraint(A <= 1);
+  known_box.add_constraint(B >= 0);
+  known_box.add_constraint(C >= 0);
+  known_box.add_constraint(C <= 1);
+  known_box.add_constraint(D >= 0);
+  known_box.add_constraint(D <= 1);
 
   bool ok = (box1 == known_box);
 
@@ -559,7 +521,7 @@ test12() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -574,12 +536,14 @@ test12() {
 bool
 test13() {
   Variable A(0);
+  Variable B(1);
+  Variable C(2);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
   // Set bounds, to check that get_covering_box clears them.
-  box1.raise_lower_bound(0, true, 1, 7);
-  box1.raise_lower_bound(1, true, 2, 7);
-  box1.raise_lower_bound(2, true, 3, 7);
+  box1.add_constraint(7*A >= 1);
+  box1.add_constraint(7*B >= 2);
+  box1.add_constraint(7*C >= 3);
 
   Grid gr(SPACE_DIM);
   gr.add_congruence((A %= 0) / 2);
@@ -587,7 +551,7 @@ test13() {
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
+  Rational_Box known_box(SPACE_DIM);
   known_box.set_empty();
 
   bool ok = (box1 == known_box);
@@ -598,11 +562,11 @@ test13() {
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
 
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     // Set bounds, to check that get_covering_box clears them.
-    box2.raise_lower_bound(0, true, 3, 7);
-    box2.raise_lower_bound(1, true, 1, 7);
-    box2.raise_lower_bound(2, true, 2, 7);
+    box2.add_constraint(7*A >= 3);
+    box2.add_constraint(7*B >= 1);
+    box2.add_constraint(7*C >= 2);
 
     tem_gr.get_covering_box(box2);
 
@@ -622,19 +586,20 @@ test14() {
   Variable A(0);
   Variable B(1);
   Variable C(2);
+  Variable D(3);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point(16*A + 14*B - 7*C, 7));
+  gr.add_grid_generator(grid_point(16*A + 14*B - 7*C, 7));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 16, 7);
-  known_box.raise_lower_bound(1, true, 2, 1);
-  known_box.raise_lower_bound(2, true, -1, 1);
-  known_box.raise_lower_bound(3, true, 0, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(7*A >= 16);
+  known_box.add_constraint(B >= 2);
+  known_box.add_constraint(C >= -1);
+  known_box.add_constraint(D >= 0);
 
   bool ok = (box1 == known_box);
 
@@ -643,7 +608,7 @@ test14() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -662,25 +627,26 @@ test15() {
   Variable A(0);
   Variable B(1);
   Variable C(2);
+  Variable D(3);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point());
-  gr.add_generator(grid_point(A, 6));
-  gr.add_generator(grid_point(B, 3));
-  gr.add_generator(grid_point(C, 2));
+  gr.add_grid_generator(grid_point());
+  gr.add_grid_generator(grid_point(A, 6));
+  gr.add_grid_generator(grid_point(B, 3));
+  gr.add_grid_generator(grid_point(C, 2));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 1, 6);
-  known_box.raise_lower_bound(1, true, 0, 1);
-  known_box.lower_upper_bound(1, true, 1, 3);
-  known_box.raise_lower_bound(2, true, 0, 1);
-  known_box.lower_upper_bound(2, true, 1, 2);
-  known_box.raise_lower_bound(3, true, 0, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A >= 0);
+  known_box.add_constraint(6*A <= 1);
+  known_box.add_constraint(B >= 0);
+  known_box.add_constraint(3*B <= 1);
+  known_box.add_constraint(C >= 0);
+  known_box.add_constraint(2*C <= 1);
+  known_box.add_constraint(D >= 0);
 
   bool ok = (box1 == known_box);
 
@@ -689,7 +655,7 @@ test15() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -706,13 +672,13 @@ test15() {
 // Zero dimension empty grid.
 bool
 test16() {
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
+  Rational_Box known_box(SPACE_DIM);
   known_box.set_empty();
 
   bool ok = (box1 == known_box);
@@ -722,7 +688,7 @@ test16() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -736,13 +702,13 @@ test16() {
 // Zero dimension universe grid.
 bool
 test17() {
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM);
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
+  Rational_Box known_box(SPACE_DIM);
 
   bool ok = (box1 == known_box);
 
@@ -751,7 +717,7 @@ test17() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -772,20 +738,20 @@ test18() {
   Variable A(0);
   Variable B(1);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point(B));
-  gr.add_generator(parameter(3*A));
-  gr.add_generator(parameter(3*A + 2*B));
+  gr.add_grid_generator(grid_point(B));
+  gr.add_grid_generator(parameter(3*A));
+  gr.add_grid_generator(parameter(3*A + 2*B));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 0, 1);
-  known_box.lower_upper_bound(0, true, 3, 1);
-  known_box.raise_lower_bound(1, true, 1, 1);
-  known_box.lower_upper_bound(1, true, 3, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A >= 0);
+  known_box.add_constraint(A <= 3);
+  known_box.add_constraint(B >= 1);
+  known_box.add_constraint(B <= 3);
 
   bool ok = (box1 == known_box);
 
@@ -794,7 +760,7 @@ test18() {
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
@@ -814,40 +780,41 @@ test19() {
   Variable A(0);
   Variable B(1);
   Variable C(2);
+  Variable D(3);
 
-  Bounding_Box box1(SPACE_DIM);
+  Rational_Box box1(SPACE_DIM);
 
   Grid gr(SPACE_DIM, EMPTY);
-  gr.add_generator(grid_point(A));
-  gr.add_generator(grid_point(7*A));
-  gr.add_generator(parameter(5*B-3*A));
-  gr.add_generator(parameter(3*A));
-  gr.add_generator(grid_point(C+A));
+  gr.add_grid_generator(grid_point(A));
+  gr.add_grid_generator(grid_point(7*A));
+  gr.add_grid_generator(parameter(5*B-3*A));
+  gr.add_grid_generator(parameter(3*A));
+  gr.add_grid_generator(grid_point(C+A));
 
   gr.get_covering_box(box1);
 
-  Bounding_Box known_box(SPACE_DIM);
-  known_box.raise_lower_bound(0, true, 1, 1);
-  known_box.lower_upper_bound(0, true, 4, 1);
-  known_box.raise_lower_bound(1, true, 0, 1);
-  known_box.lower_upper_bound(1, true, 5, 1);
-  known_box.raise_lower_bound(2, true, 0, 1);
-  known_box.lower_upper_bound(2, true, 1, 1);
-  known_box.raise_lower_bound(3, true, 0, 1);
+  Rational_Box known_box(SPACE_DIM);
+  known_box.add_constraint(A >= 1);
+  known_box.add_constraint(A <= 4);
+  known_box.add_constraint(B >= 0);
+  known_box.add_constraint(B <= 5);
+  known_box.add_constraint(C >= 0);
+  known_box.add_constraint(C <= 1);
+  known_box.add_constraint(D >= 0);
 
   bool ok = (box1 == known_box);
 
   print_generators(gr, "*** gr ***");
-  nout << "box1:" << endl << box1;
+  nout << "box1:" << endl << box1 << endl;
 
   if (ok) {
     Grid tem_gr(box1, From_Covering_Box());
-    Bounding_Box box2(SPACE_DIM);
+    Rational_Box box2(SPACE_DIM);
     tem_gr.get_covering_box(box2);
 
     ok = (box2 == known_box);
 
-    nout << "box2:" << endl << box2;
+    nout << "box2:" << endl << box2 << endl;
   }
 
   return ok;
