@@ -1,12 +1,12 @@
 /* Test operator==(const Grid&, const Grid&)
    and operator!=(const Grid&, const Grid&).
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -25,7 +25,7 @@ site: http://www.cs.unipr.it/ppl/ . */
 
 namespace {
 
-// Grids the same, gr defined by generatorss and known_gr by congruences.
+// Grids the same, gr defined by generators and known_gr by congruences.
 bool
 test01() {
   Variable A(0);
@@ -142,7 +142,7 @@ test05() {
   Variable B(1);
 
   Grid gr1(3);
-  gr1.add_congruence(A == 0);
+  gr1.add_constraint(A == 0);
 
   gr1.minimized_congruences();
 
@@ -165,15 +165,15 @@ test06() {
   Variable A(0);
 
   Grid gr1(3, EMPTY);
-  gr1.add_generator(grid_point());
+  gr1.add_grid_generator(grid_point());
 
-  gr1.minimized_generators();
+  gr1.minimized_grid_generators();
 
   Grid gr2(3, EMPTY);
-  gr2.add_generator(grid_point());
-  gr2.add_generator(grid_line(A));
+  gr2.add_grid_generator(grid_point());
+  gr2.add_grid_generator(grid_line(A));
 
-  gr2.minimized_generators();
+  gr2.minimized_grid_generators();
 
   bool ok = (gr1 != gr2);
   print_congruences(gr1, "*** gr1 ***");
@@ -190,16 +190,16 @@ test07() {
   Variable B(1);
 
   Grid gr1(3, EMPTY);
-  gr1.add_generator(grid_point());
-  gr1.add_generator(parameter(B));
+  gr1.add_grid_generator(grid_point());
+  gr1.add_grid_generator(parameter(B));
 
-  gr1.minimized_generators();
+  gr1.minimized_grid_generators();
 
   Grid gr2(3, EMPTY);
-  gr2.add_generator(grid_point());
-  gr2.add_generator(grid_line(A));
+  gr2.add_grid_generator(grid_point());
+  gr2.add_grid_generator(grid_line(A));
 
-  gr2.minimized_generators();
+  gr2.minimized_grid_generators();
 
   bool ok = (gr1 != gr2);
   print_congruences(gr1, "*** gr1 ***");
@@ -217,20 +217,20 @@ test08() {
   Variable C(2);
 
   Grid gr1(3, EMPTY);
-  gr1.add_generator(grid_point());
-  gr1.add_generator(parameter(A));
-  gr1.add_generator(parameter(B));
-  gr1.add_generator(parameter(C));
+  gr1.add_grid_generator(grid_point());
+  gr1.add_grid_generator(parameter(A));
+  gr1.add_grid_generator(parameter(B));
+  gr1.add_grid_generator(parameter(C));
 
-  gr1.minimized_generators();
+  gr1.minimized_grid_generators();
 
   Grid gr2(3, EMPTY);
-  gr2.add_generator(grid_point());
-  gr2.add_generator(parameter(2*A));
-  gr2.add_generator(parameter(2*B));
-  gr2.add_generator(parameter(2*C));
+  gr2.add_grid_generator(grid_point());
+  gr2.add_grid_generator(parameter(2*A));
+  gr2.add_grid_generator(parameter(2*B));
+  gr2.add_grid_generator(parameter(2*C));
 
-  gr2.minimized_generators();
+  gr2.minimized_grid_generators();
 
   bool ok = (gr1 != gr2);
   print_congruences(gr1, "*** gr1 ***");
@@ -239,6 +239,37 @@ test08() {
   return ok;
 }
 
+// No equalities and no lines, number of congruences and generators
+// are the same. But the generators are syntactically the same.
+bool
+test09() {
+  Variable A(0);
+  Variable B(1);
+  Variable C(2);
+
+  Grid gr1(3, EMPTY);
+  gr1.add_grid_generator(grid_point());
+  gr1.add_grid_generator(parameter(A));
+  gr1.add_grid_generator(parameter(B));
+  gr1.add_grid_generator(parameter(C));
+
+  gr1.minimized_grid_generators();
+
+  Grid gr2(3, EMPTY);
+  gr2.add_grid_generator(grid_point());
+  gr2.add_grid_generator(parameter(A));
+  gr2.add_grid_generator(parameter(B));
+  gr2.add_grid_generator(parameter(C));
+
+  gr2.minimized_grid_generators();
+
+  bool ok = (gr1 == gr2);
+  print_congruences(gr1, "*** gr1 ***");
+  print_congruences(gr2, "*** gr2 ***");
+
+  return ok;
+}
+
 } // namespace
 
 BEGIN_MAIN
@@ -250,4 +281,5 @@ BEGIN_MAIN
   DO_TEST(test06);
   DO_TEST(test07);
   DO_TEST(test08);
+  DO_TEST(test09);
 END_MAIN
