@@ -1,11 +1,11 @@
 /* Test Grid::generalized_affine_image(lhs, rhs, modulus).
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -39,16 +39,16 @@ test01() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(1*B, Linear_Expression::zero(), 0);
+  gr.generalized_affine_image(1*B, EQUAL, Linear_Expression::zero(), 0);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_point(A));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_point(A));
 
   bool ok = (gr == known_gr);
 
   print_congruences(gr,
-   "*** gr.generalized_affine_image(1*B, Linear_Expression::zero(), 0) ***");
+		    "*** gr.generalized_affine_image(1*B, Linear_Expression::zero(), 0) ***");
 
   return ok;
 }
@@ -65,17 +65,17 @@ test02() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(2*B, Linear_Expression::zero());
+  gr.generalized_affine_image(2*B, EQUAL, Linear_Expression::zero(), 1);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_point(A));
-  known_gr.add_generator(grid_point(B, 2));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_point(A));
+  known_gr.add_grid_generator(grid_point(B, 2));
 
   bool ok = (gr == known_gr);
 
   print_congruences(gr,
-    "*** gr.generalized_affine_image(2*B, Linear_Expression::zero()) ***");
+		    "*** gr.generalized_affine_image(2*B, Linear_Expression::zero()) ***");
 
   return ok;
 }
@@ -92,17 +92,16 @@ test03() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(1*B, A + 1);
+  gr.generalized_affine_image(1*B, EQUAL, A + 1, 1);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_point(A - B));
-  known_gr.add_generator(grid_point(B));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_point(A - B));
+  known_gr.add_grid_generator(grid_point(B));
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.generalized_affine_image(1*B, A + 1) ***");
+  print_congruences(gr, "*** gr.generalized_affine_image(1*B, A + 1) ***");
 
   return ok;
 }
@@ -119,17 +118,16 @@ test04() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(2*B, A + 1);
+  gr.generalized_affine_image(2*B, EQUAL, A + 1, 1);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_point(A));
-  known_gr.add_generator(grid_point(B, 2));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_point(A));
+  known_gr.add_grid_generator(grid_point(B, 2));
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.generalized_affine_image(2*B, A + 1) ***");
+  print_congruences(gr, "*** gr.generalized_affine_image(2*B, A + 1) ***");
 
   return ok;
 }
@@ -146,17 +144,16 @@ test05() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(2*B, A + 1, 3);
+  gr.generalized_affine_image(2*B, EQUAL, A + 1, 3);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point(B, 2));
-  known_gr.add_generator(grid_point(A + B));
-  known_gr.add_generator(grid_point(2*B));
+  known_gr.add_grid_generator(grid_point(B, 2));
+  known_gr.add_grid_generator(grid_point(A + B));
+  known_gr.add_grid_generator(grid_point(2*B));
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.generalized_affine_image(2*B, A + 1, 3) ***");
+  print_congruences(gr, "*** gr.generalized_affine_image(2*B, A + 1, 3) ***");
 
   return ok;
 }
@@ -173,17 +170,16 @@ test06() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(2*B, A + 1, 3);
+  gr.generalized_affine_image(2*B, EQUAL, A + 1, 3);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point(B, 2));
-  known_gr.add_generator(grid_point(A + B));
-  known_gr.add_generator(grid_point(2*B));
+  known_gr.add_grid_generator(grid_point(B, 2));
+  known_gr.add_grid_generator(grid_point(A + B));
+  known_gr.add_grid_generator(grid_point(2*B));
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.generalized_affine_image(2*B, A + 1, 3) ***");
+  print_congruences(gr, "*** gr.generalized_affine_image(2*B, A + 1, 3) ***");
 
   return ok;
 }
@@ -200,17 +196,16 @@ test07() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(-2*B, A + 2);
+  gr.generalized_affine_image(-2*B, EQUAL, A + 2, 1);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point(-B, 2));
-  known_gr.add_generator(grid_point(2*A + -3*B, 2));
-  known_gr.add_generator(grid_point(-B));
+  known_gr.add_grid_generator(grid_point(-B, 2));
+  known_gr.add_grid_generator(grid_point(2*A + -3*B, 2));
+  known_gr.add_grid_generator(grid_point(-B));
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.generalized_affine_image(-2*B, A + 2) ***");
+  print_congruences(gr, "*** gr.generalized_affine_image(-2*B, A + 2) ***");
 
   return ok;
 }
@@ -227,17 +222,16 @@ test08() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(1*B, A + 2, -7);
+  gr.generalized_affine_image(1*B, EQUAL, A + 2, -7);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point(2*B));
-  known_gr.add_generator(grid_point(A + 3*B));
-  known_gr.add_generator(grid_point(9*B));
+  known_gr.add_grid_generator(grid_point(2*B));
+  known_gr.add_grid_generator(grid_point(A + 3*B));
+  known_gr.add_grid_generator(grid_point(9*B));
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.generalized_affine_image(1*B, A + 2, -7) ***");
+  print_congruences(gr, "*** gr.generalized_affine_image(1*B, A + 2, -7) ***");
 
   return ok;
 }
@@ -255,19 +249,19 @@ test09() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(1*A, A - C + 2, 5);
+  gr.generalized_affine_image(1*A, EQUAL, A - C + 2, 5);
 
   Grid known_gr(3, EMPTY);
-  known_gr.add_generator(grid_point(2*A));
-  known_gr.add_generator(grid_point(2*A + 3*B));
-  known_gr.add_generator(grid_line(A + C));
-  known_gr.add_generator(grid_point(4*A));  // Original modulus.
-  known_gr.add_generator(grid_point(7*A));  // Transformation modulus.
+  known_gr.add_grid_generator(grid_point(2*A));
+  known_gr.add_grid_generator(grid_point(2*A + 3*B));
+  known_gr.add_grid_generator(grid_line(A + C));
+  known_gr.add_grid_generator(grid_point(4*A));  // Original modulus.
+  known_gr.add_grid_generator(grid_point(7*A));  // Transformation modulus.
 
   bool ok = (gr == known_gr);
 
   print_congruences(gr,
-        "*** gr.generalized_affine_image(1*A, A - C + 2, 5) ***");
+		    "*** gr.generalized_affine_image(1*A, A - C + 2, 5) ***");
 
   return ok;
 }
@@ -285,7 +279,7 @@ test10() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(1*A, A - C + 2, 0);
+  gr.generalized_affine_image(1*A, EQUAL, A - C + 2, 0);
 
   Grid known_gr = Grid(3);
   known_gr.add_congruence((B %= 0) / 3);
@@ -296,7 +290,7 @@ test10() {
   bool ok = (gr == known_gr);
 
   print_congruences(gr,
-        "*** gr.generalized_affine_image(1*A, A - C + 2, 0) ***");
+		    "*** gr.generalized_affine_image(1*A, A - C + 2, 0) ***");
 
   return ok;
 }
@@ -312,14 +306,13 @@ test11() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(4*A, A - 2*C + 3, 7);
+  gr.generalized_affine_image(4*A, EQUAL, A - 2*C + 3, 7);
 
   Grid known_gr(5, EMPTY);
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.generalized_affine_image(1*A, A + 2) ***");
+  print_congruences(gr, "*** gr.generalized_affine_image(1*A, A + 2) ***");
 
   return ok;
 }
@@ -330,19 +323,18 @@ test12() {
   Variable A(0);
 
   Grid gr(1);
-  gr.add_congruence(A == 0);
-  gr.add_congruence(A == 3);
+  gr.add_constraint(A == 0);
+  gr.add_constraint(A == 3);
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(1*A, A + 2);
+  gr.generalized_affine_image(1*A, EQUAL, A + 2, 1);
 
   Grid known_gr(1, EMPTY);
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.generalized_affine_image(1*A, A + 2) ***");
+  print_congruences(gr, "*** gr.generalized_affine_image(1*A, A + 2) ***");
 
   return ok;
 }
@@ -356,14 +348,13 @@ test13() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(1*A, A + 2);
+  gr.generalized_affine_image(1*A, EQUAL, A + 2, 1);
 
   Grid known_gr(1);
 
   bool ok = (gr == known_gr);
 
-  print_congruences(gr,
-        "*** gr.generalized_affine_image(1*A, A + 2) ***");
+  print_congruences(gr, "*** gr.generalized_affine_image(1*A, A + 2) ***");
 
   return ok;
 }
@@ -379,18 +370,18 @@ test14() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(Linear_Expression::zero(),
-			      Linear_Expression(1));
+  gr.generalized_affine_image(Linear_Expression::zero(), EQUAL,
+			      Linear_Expression(1), 1);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_point(A));
-  known_gr.add_generator(grid_line(B));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_point(A));
+  known_gr.add_grid_generator(grid_line(B));
 
   bool ok = (gr == known_gr);
 
   print_congruences(gr,
-    "*** gr.generalized_affine_image(Linear_Expression::zero(), Linear_Expression(1)) ***");
+		    "*** gr.generalized_affine_image(Linear_Expression::zero(), EQUAL, Linear_Expression(1), 1) ***");
 
   return ok;
 }
@@ -406,17 +397,17 @@ test15() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(Linear_Expression::zero(), A - B, 5);
+  gr.generalized_affine_image(Linear_Expression::zero(), EQUAL, A - B, 5);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_point(A + B));
-  known_gr.add_generator(grid_point(5*A));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_point(A + B));
+  known_gr.add_grid_generator(grid_point(5*A));
 
   bool ok = (gr == known_gr);
 
   print_congruences(gr,
-   "*** gr.generalized_affine_image(Linear_Expression::zero(), A - B, 5) ***");
+		    "*** gr.generalized_affine_image(Linear_Expression::zero(), EQUAL, A - B, 5) ***");
 
   return ok;
 }
@@ -429,23 +420,23 @@ test16() {
   Variable C(2);
 
   Grid gr(3);
-  gr.add_congruence(A - B == 0);
+  gr.add_constraint(A - B == 0);
   gr.add_congruence((C %= 0) / 3);
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(A - B, C);
+  gr.generalized_affine_image(A - B, EQUAL, C, 1);
 
   Grid known_gr(3, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_line(A + B));
-  known_gr.add_generator(grid_point(B));
-  known_gr.add_generator(grid_point(3*C));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_line(A + B));
+  known_gr.add_grid_generator(grid_point(B));
+  known_gr.add_grid_generator(grid_point(3*C));
 
   bool ok = (gr == known_gr);
 
   print_congruences(gr,
-        "*** gr.generalized_affine_image(A - B, C) ***");
+		    "*** gr.generalized_affine_image(A - B, EQUAL, C, 1) ***");
 
   return ok;
 }
@@ -457,18 +448,18 @@ test17() {
   Variable B(1);
 
   Grid gr(2);
-  gr.add_congruence(A - B == 0);
+  gr.add_constraint(A - B == 0);
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(A - B, A, 0);
+  gr.generalized_affine_image(A - B, EQUAL, A);
 
   Grid known_gr(2);
 
   bool ok = (gr == known_gr);
 
   print_congruences(gr,
-        "*** gr.generalized_affine_image(A - B, A, 0) ***");
+		    "*** gr.generalized_affine_image(A - B, EQUAL, A) ***");
 
   return ok;
 }
@@ -485,17 +476,17 @@ test18() {
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(A + 2*B, A - B, 3);
+  gr.generalized_affine_image(A + 2*B, EQUAL, A - B, 3);
 
   Grid known_gr(2, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_point(B, 2));
-  known_gr.add_generator(grid_line(2*A - B));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_point(B, 2));
+  known_gr.add_grid_generator(grid_line(2*A - B));
 
   bool ok = (gr == known_gr);
 
   print_congruences(gr,
-        "*** gr.generalized_affine_image(A + 2*B, A - B, 3) ***");
+		    "*** gr.generalized_affine_image(A + 2*B, EQUAL, A - B, 3) ***");
 
   return ok;
 }
@@ -509,20 +500,20 @@ test19() {
   Variable C(2);
 
   Grid gr(3);
-  gr.add_congruence(C == 0);
-  gr.add_congruence(A + 3*B == 2);
+  gr.add_constraint(C == 0);
+  gr.add_constraint(A + 3*B == 2);
 
   print_congruences(gr, "*** gr ***");
 
-  gr.generalized_affine_image(A - C, B + 3, 0);
+  gr.generalized_affine_image(A - C, EQUAL, B + 3, 0);
 
   Grid known_gr(3);
-  known_gr.add_congruence(A - C == B + 3);
+  known_gr.add_constraint(A - C == B + 3);
 
   bool ok = (gr == known_gr);
 
   print_congruences(gr,
-        "*** gr.generalized_affine_image(A - C, B + 3, 0) ***");
+		    "*** gr.generalized_affine_image(A - C, EQUAL, B + 3, 0) ***");
 
   return ok;
 }
