@@ -1,11 +1,11 @@
-/* Test Grid::limited_extrapolation_assign().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+/* Test Grid::limited_congruence_extrapolation_assign().
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -40,11 +40,11 @@ test01() {
 
   Grid known_gr = gr2;
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
@@ -55,8 +55,8 @@ test02() {
   Variable A(0);
 
   Grid gr1(1);
-  gr1.add_congruence(A == 0);
-  gr1.add_congruence(A == 1);
+  gr1.add_constraint(A == 0);
+  gr1.add_constraint(A == 1);
   print_congruences(gr1, "*** gr1 ***");
 
   Grid gr2(1);
@@ -67,11 +67,11 @@ test02() {
 
   Grid known_gr = gr2;
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
@@ -83,12 +83,12 @@ test03() {
   Variable B(1);
 
   Grid gr1(2);
-  gr1.add_congruence(A == 0);
-  gr1.add_congruence(B == 1);
+  gr1.add_constraint(A == 0);
+  gr1.add_constraint(B == 1);
   print_congruences(gr1, "*** gr1 ***");
 
   Grid gr2(2);
-  gr2.add_congruence(A == 0);
+  gr2.add_constraint(A == 0);
   gr2.add_congruence(B %= 1);
   print_congruences(gr2, "*** gr2 ***");
 
@@ -96,11 +96,11 @@ test03() {
 
   Congruence_System cgs(B %= 0);
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
@@ -127,11 +127,11 @@ test04() {
 
   Congruence_System cgs(C %= 0);
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
@@ -159,11 +159,11 @@ test05() {
 
   Grid known_gr = gr2;
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
@@ -179,13 +179,13 @@ test06() {
 
   Congruence_System cgs(0*E %= 0);
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   Grid known_gr(5);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
@@ -210,13 +210,13 @@ test07() {
   cgs.insert(A %= 0);
   cgs.insert(B %= 0);
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   Grid known_gr(cgs);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
@@ -242,7 +242,7 @@ test08() {
 
   Grid known_gr = gr2;
 
-  gr2.limited_extrapolation_assign(gr1, cgs, &tokens);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs, &tokens);
 
 #undef TOKENS
 #define TOKENS 5
@@ -251,8 +251,7 @@ test08() {
 
   nout << "tokens: before " << TOKENS << ", after " << tokens << endl;
 
-  print_congruences(gr2,
-     "*** gr2.limited_extrapolation_assign(gr1, cgs, &tokens) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs, &tokens) ***");
 
   return ok;
 }
@@ -281,14 +280,13 @@ test09() {
 
   Grid known_gr(2);
 
-  gr2.limited_extrapolation_assign(gr1, cgs, &tokens);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs, &tokens);
 
   bool ok = (gr2 == known_gr) && (tokens == TOKENS);
 
   nout << "tokens: before " << TOKENS << ", after " << tokens << endl;
 
-  print_congruences(gr2,
-     "*** gr2.limited_extrapolation_assign(gr1, cgs, &tokens) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs, &tokens) ***");
 
   return ok;
 }
@@ -305,13 +303,13 @@ test10() {
   Congruence_System cgs(
      (Linear_Expression::zero() %= Linear_Expression::zero()) / 4);
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   Grid known_gr(0);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
@@ -335,7 +333,7 @@ test11() {
   Congruence_System cgs;
   cgs.insert((A - B == 0) / 3);
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   Grid known_gr(2);
   known_gr.add_congruence(A %= 0);
@@ -343,7 +341,7 @@ test11() {
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
@@ -356,15 +354,15 @@ test12() {
   Variable C(2);
 
   Grid gr1(3, EMPTY);
-  gr1.add_generator(grid_point(C, 3));
-  gr1.add_generator(grid_line(A - 2*B));
-  gr1.add_generator(grid_point(C + 3*A + 3*C, 3));
+  gr1.add_grid_generator(grid_point(C, 3));
+  gr1.add_grid_generator(grid_line(A - 2*B));
+  gr1.add_grid_generator(grid_point(C + 3*A + 3*C, 3));
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(3, EMPTY);
-  gr2.add_generator(grid_point(C, 3));
-  gr2.add_generator(grid_line(A - 2*B));
-  gr2.add_generator(grid_line(A + C));
+  gr2.add_grid_generator(grid_point(C, 3));
+  gr2.add_grid_generator(grid_line(A - 2*B));
+  gr2.add_grid_generator(grid_line(A + C));
   print_generators(gr2, "*** gr2 ***");
 
   Grid known_gr = gr2;
@@ -372,11 +370,11 @@ test12() {
   Congruence_System cgs;
   cgs.insert(A - 0*C == 3);
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
@@ -389,28 +387,28 @@ test13() {
   Variable C(2);
 
   Grid gr1(3, EMPTY);
-  gr1.add_generator(grid_point(C, 3));
-  gr1.add_generator(grid_point(C + A - 2*B, 3));
+  gr1.add_grid_generator(grid_point(C, 3));
+  gr1.add_grid_generator(grid_point(C + A - 2*B, 3));
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(5, EMPTY);
-  gr2.add_generator(grid_point(C, 3));
-  gr2.add_generator(grid_point(2*C + A - 2*B, 6));
+  gr2.add_grid_generator(grid_point(C, 3));
+  gr2.add_grid_generator(grid_point(2*C + A - 2*B, 6));
   print_generators(gr2, "*** gr2 ***");
 
   Congruence_System cgs;
   cgs.insert(A - 0*C == 3);
 
   try {
-    gr2.limited_extrapolation_assign(gr1, cgs);
+    gr2.limited_congruence_extrapolation_assign(gr1, cgs);
   }
   catch (const std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl;
+    return true;
   }
   catch (...) {
-    return false;
   }
-  return true;
+  return false;
 }
 
 // Exception due to space dimension of congruence system.
@@ -421,28 +419,28 @@ test14() {
   Variable C(2);
 
   Grid gr1(2, EMPTY);
-  gr1.add_generator(grid_point(A));
-  gr1.add_generator(parameter(B, 3));
+  gr1.add_grid_generator(grid_point(A));
+  gr1.add_grid_generator(parameter(B, 3));
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(2, EMPTY);
-  gr2.add_generator(grid_point(A));
-  gr2.add_generator(parameter(B, 6));
+  gr2.add_grid_generator(grid_point(A));
+  gr2.add_grid_generator(parameter(B, 6));
   print_generators(gr2, "*** gr2 ***");
 
   Congruence_System cgs;
   cgs.insert(A - 0*C == 3);
 
   try {
-    gr2.limited_extrapolation_assign(gr1, cgs);
+    gr2.limited_congruence_extrapolation_assign(gr1, cgs);
   }
   catch (const std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl;
+    return true;
   }
   catch (...) {
-    return false;
   }
-  return true;
+  return false;
 }
 
 // Limit with an empty congruence system.
@@ -451,26 +449,26 @@ test15() {
   Variable A(0);
 
   Grid gr1(3, EMPTY);
-  gr1.add_generator(grid_point());
-  gr1.add_generator(parameter(A, 3));
+  gr1.add_grid_generator(grid_point());
+  gr1.add_grid_generator(parameter(A, 3));
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(3, EMPTY);
-  gr2.add_generator(grid_point());
-  gr2.add_generator(parameter(A, 6));
+  gr2.add_grid_generator(grid_point());
+  gr2.add_grid_generator(parameter(A, 6));
   print_generators(gr2, "*** gr2 ***");
 
   Congruence_System cgs;
 
-  gr2.limited_extrapolation_assign(gr1, cgs);
+  gr2.limited_congruence_extrapolation_assign(gr1, cgs);
 
   Grid known_gr = gr2;
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_line(A));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_line(A));
 
   bool ok = (gr2 == known_gr);
 
-  print_congruences(gr2, "*** gr2.limited_extrapolation_assign(gr1, cgs) ***");
+  print_congruences(gr2, "*** gr2.limited_congruence_extrapolation_assign(gr1, cgs) ***");
 
   return ok;
 }
