@@ -1,12 +1,12 @@
 /* Test Grid::maximize(const Linear_Expression&, ...)
    and Grid::minimize(const Linear_Expression&, ...).
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -22,19 +22,21 @@ For the most up-to-date information see the Parma Polyhedra Library
 site: http://www.cs.unipr.it/ppl/ . */
 
 #include "ppl_test.hh"
+#include <string>
 
 using namespace Parma_Polyhedra_Library::IO_Operators;
 
 namespace {
 
 bool
-check_both(Grid& gr, Linear_Expression& le, string grid_name) {
-  Grid_Generator ext_pnt(grid_point());
+check_both(Grid& gr, const Linear_Expression& le,
+	   const std::string grid_name) {
+  Generator ext_pnt(point());
   bool dummy;
   Coefficient ext_n, ext_d;
 
-  bool ok = (!gr.minimize(le, ext_n, ext_d, dummy, ext_pnt)
-      && !gr.maximize(le, ext_n, ext_d, dummy, ext_pnt));
+  bool ok = (!gr.maximize(le, ext_n, ext_d, dummy, ext_pnt)
+	     && !gr.minimize(le, ext_n, ext_d, dummy, ext_pnt));
 
   if (!ok)
     nout << grid_name << " bounded expr" << endl;
@@ -43,43 +45,47 @@ check_both(Grid& gr, Linear_Expression& le, string grid_name) {
 }
 
 bool
-check_minimize(Grid& gr, Linear_Expression& le,
-	       Coefficient expected_n, Coefficient expected_d,
-	       Grid_Generator& expected_pnt, string grid_name) {
-  Grid_Generator inf_pnt(grid_point());
+check_minimize(Grid& gr, const Linear_Expression& le,
+	       Coefficient_traits::const_reference expected_n,
+	       Coefficient_traits::const_reference expected_d,
+	       const Generator& expected_pnt,
+	       const std::string grid_name) {
+  Generator inf_pnt(point());
 
   bool dummy;
   Coefficient inf_n, inf_d;
 
   bool ok = (gr.minimize(le, inf_n, inf_d, dummy, inf_pnt)
-    && inf_n == expected_n
-    && inf_d == expected_d
-    && inf_pnt == expected_pnt);
+	     && inf_n == expected_n
+	     && inf_d == expected_d
+	     && inf_pnt == expected_pnt);
 
   if (!ok)
     nout << "grid name " << grid_name << " min point " << inf_pnt
-	        << " (expected " << expected_pnt << ")" << endl;
+	 << " (expected " << expected_pnt << ")" << endl;
 
   return ok;
 }
 
 bool
-check_maximize(Grid& gr, Linear_Expression& le,
-	       Coefficient expected_n, Coefficient expected_d,
-	       Grid_Generator& expected_pnt, string grid_name) {
-  Grid_Generator sup_pnt(grid_point());
+check_maximize(Grid& gr, const Linear_Expression& le,
+	       Coefficient_traits::const_reference expected_n,
+	       Coefficient_traits::const_reference expected_d,
+	       const Generator& expected_pnt,
+	       const std::string grid_name) {
+  Generator sup_pnt(point());
 
   bool dummy;
   Coefficient sup_n, sup_d;
 
   bool ok = (gr.maximize(le, sup_n, sup_d, dummy, sup_pnt)
-    && sup_n == expected_n
-    && sup_d == expected_d
+	     && sup_n == expected_n
+	     && sup_d == expected_d
 	     && sup_pnt == expected_pnt);
 
   if (!ok)
     nout << "grid name " << grid_name << " max point " << sup_pnt
-	        << " (expected " << expected_pnt << ")" << endl;
+	 << " (expected " << expected_pnt << ")" << endl;
 
   return ok;
 }
@@ -91,7 +97,7 @@ test01() {
 
   Coefficient extr_n, extr_d;
   bool dummy;
-  Grid_Generator pnt(grid_point());
+  Generator pnt(point());
 
   bool ok = (!gr.maximize(Linear_Expression(0), extr_n, extr_d, dummy, pnt)
 	     && !gr.minimize(Linear_Expression(0), extr_n, extr_d, dummy, pnt));
@@ -117,7 +123,7 @@ test03() {
 
   Linear_Expression le = Linear_Expression::zero();
 
-  Grid_Generator exp_pnt(grid_point());
+  Generator exp_pnt(point());
 
   bool ok = check_maximize(gr, le, 0, 1, exp_pnt, "gr")
     && check_minimize(gr, le, 0, 1, exp_pnt, "gr");
@@ -132,24 +138,24 @@ test04() {
   Variable B(1);
 
   Grid gr_gs_min(2, EMPTY);
-  gr_gs_min.add_generator_and_minimize(grid_point(3*A + 2*B, 3));
+  gr_gs_min.add_grid_generator_and_minimize(grid_point(3*A + 2*B, 3));
   print_generators(gr_gs_min, "*** gr_gs_min ***");
 
   Grid gr_gs_needs_min(2, EMPTY);
-  gr_gs_needs_min.add_generator(grid_point(3*A + 2*B, 3));
+  gr_gs_needs_min.add_grid_generator(grid_point(3*A + 2*B, 3));
   print_generators(gr_gs_needs_min, "*** gr_gs_needs_min ***");
 
   Grid gr_cgs_needs_min(2);
-  gr_cgs_needs_min.add_congruence(A == 1);
-  gr_cgs_needs_min.add_congruence(3*B == 2);
+  gr_cgs_needs_min.add_constraint(A == 1);
+  gr_cgs_needs_min.add_constraint(3*B == 2);
   print_congruences(gr_cgs_needs_min, "*** gr_cgs_needs_min ***");
 
-  assert(copy_compare(gr_gs_min, gr_gs_needs_min));
-  assert(copy_compare(gr_gs_needs_min, gr_cgs_needs_min));
+  // Grids gr_gs_min, gr_gs_needs_min and gr_cgs_needs_min are the
+  // same grids.
 
   Linear_Expression le = A + B;
 
-  Grid_Generator exp_pnt(grid_point(3*A + 2*B, 3));
+  Generator exp_pnt(point(3*A + 2*B, 3));
 
   bool ok = check_maximize(gr_gs_min, le, 5, 3, exp_pnt, "gr_gs_min")
     && check_minimize(gr_gs_min, le, 5, 3, exp_pnt, "gr_gs_min");
@@ -172,21 +178,21 @@ test05() {
   Variable B(1);
 
   Grid gr_gs_min(2, EMPTY);
-  gr_gs_min.add_generator(grid_point());
-  gr_gs_min.add_generator_and_minimize(grid_line(B));
+  gr_gs_min.add_grid_generator(grid_point());
+  gr_gs_min.add_grid_generator_and_minimize(grid_line(B));
   print_generators(gr_gs_min, "*** gr_gs_min ***");
 
   Grid gr_gs_needs_min(2, EMPTY);
-  gr_gs_needs_min.add_generator(grid_point());
-  gr_gs_needs_min.add_generator(grid_line(B));
+  gr_gs_needs_min.add_grid_generator(grid_point());
+  gr_gs_needs_min.add_grid_generator(grid_line(B));
   print_generators(gr_gs_needs_min, "*** gr_gs_needs_min ***");
 
   Grid gr_cgs_needs_min(2);
-  gr_cgs_needs_min.add_congruence(A == 0);
+  gr_cgs_needs_min.add_constraint(A == 0);
   print_congruences(gr_cgs_needs_min, "*** gr_cgs_needs_min ***");
 
-  assert(copy_compare(gr_gs_min, gr_gs_needs_min));
-  assert(copy_compare(gr_gs_needs_min, gr_cgs_needs_min));
+  // Grids gr_gs_min, gr_gs_needs_min and gr_cgs_needs_min are the
+  // same grids.
 
   Linear_Expression le = 2*A - B;
 
@@ -204,21 +210,21 @@ test06() {
   Variable B(1);
 
   Grid gr_gs_min(2, EMPTY);
-  gr_gs_min.add_generator(grid_point());
-  gr_gs_min.add_generator_and_minimize(grid_line(2*A + B));
+  gr_gs_min.add_grid_generator(grid_point());
+  gr_gs_min.add_grid_generator_and_minimize(grid_line(2*A + B));
   print_generators(gr_gs_min, "*** gr_gs_min ***");
 
   Grid gr_gs_needs_min(2, EMPTY);
-  gr_gs_needs_min.add_generator(grid_point());
-  gr_gs_needs_min.add_generator(grid_line(2*A + B));
+  gr_gs_needs_min.add_grid_generator(grid_point());
+  gr_gs_needs_min.add_grid_generator(grid_line(2*A + B));
   print_generators(gr_gs_needs_min, "*** gr_gs_needs_min ***");
 
   Grid gr_cgs_needs_min(2);
-  gr_cgs_needs_min.add_congruence(A - 2*B == 0);
+  gr_cgs_needs_min.add_constraint(A - 2*B == 0);
   print_congruences(gr_cgs_needs_min, "*** gr_cgs_needs_min ***");
 
-  assert(copy_compare(gr_gs_min, gr_gs_needs_min));
-  assert(copy_compare(gr_gs_needs_min, gr_cgs_needs_min));
+  // Grids gr_gs_min, gr_gs_needs_min and gr_cgs_needs_min are the
+  // same grids.
 
   Linear_Expression le = 2*A + B;
 
@@ -236,25 +242,25 @@ test07() {
   Variable B(1);
 
   Grid gr_gs_min(2, EMPTY);
-  gr_gs_min.add_generator(grid_point());
-  gr_gs_min.add_generator_and_minimize(grid_line(A + 2*B));
+  gr_gs_min.add_grid_generator(grid_point());
+  gr_gs_min.add_grid_generator_and_minimize(grid_line(A + 2*B));
   print_generators(gr_gs_min, "*** gr_gs_min ***");
 
   Grid gr_gs_needs_min(2, EMPTY);
-  gr_gs_needs_min.add_generator(grid_point());
-  gr_gs_needs_min.add_generator(grid_line(A + 2*B));
+  gr_gs_needs_min.add_grid_generator(grid_point());
+  gr_gs_needs_min.add_grid_generator(grid_line(A + 2*B));
   print_generators(gr_gs_needs_min, "*** gr_gs_needs_min ***");
 
   Grid gr_cgs_needs_min(2);
-  gr_cgs_needs_min.add_congruence(2*A - B == 0);
+  gr_cgs_needs_min.add_constraint(2*A - B == 0);
   print_congruences(gr_cgs_needs_min, "*** gr_cgs_needs_min ***");
 
-  assert(copy_compare(gr_gs_min, gr_gs_needs_min));
-  assert(copy_compare(gr_gs_needs_min, gr_cgs_needs_min));
+  // Grids gr_gs_min, gr_gs_needs_min and gr_cgs_needs_min are the
+  // same grids.
 
   Linear_Expression le = 2*A - B;
 
-  Grid_Generator exp_pnt(grid_point(0*B));
+  Generator exp_pnt(point(0*B));
 
   bool ok = check_maximize(gr_gs_min, le, 0, 1, exp_pnt, "gr_gs_min")
     && check_minimize(gr_gs_min, le, 0, 1, exp_pnt, "gr_gs_min");
@@ -277,26 +283,26 @@ test08() {
   Variable B(1);
 
   Grid gr_gs_min(2, EMPTY);
-  gr_gs_min.add_generator(grid_point());
-  gr_gs_min.add_generator_and_minimize(grid_point(A + 2*B));
+  gr_gs_min.add_grid_generator(grid_point());
+  gr_gs_min.add_grid_generator_and_minimize(grid_point(A + 2*B));
   print_generators(gr_gs_min, "*** gr_gs_min ***");
 
   Grid gr_gs_needs_min(2, EMPTY);
-  gr_gs_needs_min.add_generator(grid_point());
-  gr_gs_needs_min.add_generator(grid_point(A + 2*B));
+  gr_gs_needs_min.add_grid_generator(grid_point());
+  gr_gs_needs_min.add_grid_generator(grid_point(A + 2*B));
   print_generators(gr_gs_needs_min, "*** gr_gs_needs_min ***");
 
   Grid gr_cgs_needs_min(2);
-  gr_cgs_needs_min.add_congruence(2*A - B == 0);
+  gr_cgs_needs_min.add_constraint(2*A - B == 0);
   gr_cgs_needs_min.add_congruence((B %= 0) / 2);
   print_congruences(gr_cgs_needs_min, "*** gr_cgs_needs_min ***");
 
-  assert(copy_compare(gr_gs_min, gr_gs_needs_min));
-  assert(copy_compare(gr_gs_needs_min, gr_cgs_needs_min));
+  // Grids gr_gs_min, gr_gs_needs_min and gr_cgs_needs_min are the
+  // same grids.
 
   Linear_Expression le = 2*A - B;
 
-  Grid_Generator exp_pnt(grid_point(0*B));
+  Generator exp_pnt(point(0*B));
 
   bool ok = check_maximize(gr_gs_min, le, 0, 1, exp_pnt, "gr_gs_min")
     && check_minimize(gr_gs_min, le, 0, 1, exp_pnt, "gr_gs_min");
@@ -319,22 +325,22 @@ test09() {
   Variable B(1);
 
   Grid gr_gs_min(2, EMPTY);
-  gr_gs_min.add_generator(grid_point());
-  gr_gs_min.add_generator(grid_line(A));
-  gr_gs_min.add_generator_and_minimize(grid_line(B));
+  gr_gs_min.add_grid_generator(grid_point());
+  gr_gs_min.add_grid_generator(grid_line(A));
+  gr_gs_min.add_grid_generator_and_minimize(grid_line(B));
   print_generators(gr_gs_min, "*** gr_gs_min ***");
 
   Grid gr_gs_needs_min(2, EMPTY);
-  gr_gs_needs_min.add_generator(grid_point());
-  gr_gs_needs_min.add_generator(grid_line(A));
-  gr_gs_needs_min.add_generator(grid_line(B));
+  gr_gs_needs_min.add_grid_generator(grid_point());
+  gr_gs_needs_min.add_grid_generator(grid_line(A));
+  gr_gs_needs_min.add_grid_generator(grid_line(B));
   print_generators(gr_gs_needs_min, "*** gr_gs_needs_min ***");
 
   Grid gr_cgs_needs_min(2);
   print_congruences(gr_cgs_needs_min, "*** gr_cgs_needs_min ***");
 
-  assert(copy_compare(gr_gs_min, gr_gs_needs_min));
-  assert(copy_compare(gr_gs_needs_min, gr_cgs_needs_min));
+  // Grids gr_gs_min, gr_gs_needs_min and gr_cgs_needs_min are the
+  // same grids.
 
   Linear_Expression le = A - B;
 
@@ -354,24 +360,24 @@ test10() {
   Variable C(2);
 
   Grid gr_gs_min(3, EMPTY);
-  gr_gs_min.add_generator(grid_point());
-  gr_gs_min.add_generator(grid_line(A));
-  gr_gs_min.add_generator_and_minimize(grid_point(B + C));
+  gr_gs_min.add_grid_generator(grid_point());
+  gr_gs_min.add_grid_generator(grid_line(A));
+  gr_gs_min.add_grid_generator_and_minimize(grid_point(B + C));
   print_generators(gr_gs_min, "*** gr_gs_min ***");
 
   Grid gr_gs_needs_min(3, EMPTY);
-  gr_gs_needs_min.add_generator(grid_point());
-  gr_gs_needs_min.add_generator(grid_line(A));
-  gr_gs_needs_min.add_generator(grid_point(B + C));
+  gr_gs_needs_min.add_grid_generator(grid_point());
+  gr_gs_needs_min.add_grid_generator(grid_line(A));
+  gr_gs_needs_min.add_grid_generator(grid_point(B + C));
   print_generators(gr_gs_needs_min, "*** gr_gs_needs_min ***");
 
   Grid gr_cgs_needs_min(3);
-  gr_cgs_needs_min.add_congruence(B - C == 0);
+  gr_cgs_needs_min.add_constraint(B - C == 0);
   gr_cgs_needs_min.add_congruence(B %= 0);
   print_congruences(gr_cgs_needs_min, "*** gr_cgs_needs_min ***");
 
-  assert(copy_compare(gr_gs_min, gr_gs_needs_min));
-  assert(copy_compare(gr_gs_needs_min, gr_cgs_needs_min));
+  // Grids gr_gs_min, gr_gs_needs_min and gr_cgs_needs_min are the
+  // same grids.
 
   Linear_Expression le = 2*A + B - C;
 
@@ -390,27 +396,27 @@ test11() {
   Variable C(2);
 
   Grid gr_gs_min(3, EMPTY);
-  gr_gs_min.add_generator(grid_point(A));
-  gr_gs_min.add_generator(grid_line(3*B + C));
-  gr_gs_min.add_generator_and_minimize(grid_line(A - 2*B));
+  gr_gs_min.add_grid_generator(grid_point(A));
+  gr_gs_min.add_grid_generator(grid_line(3*B + C));
+  gr_gs_min.add_grid_generator_and_minimize(grid_line(A - 2*B));
   print_generators(gr_gs_min, "*** gr_gs_min ***");
 
   Grid gr_gs_needs_min(3, EMPTY);
-  gr_gs_needs_min.add_generator(grid_point(A));
-  gr_gs_needs_min.add_generator(grid_line(3*B + C));
-  gr_gs_needs_min.add_generator(grid_line(A - 2*B));
+  gr_gs_needs_min.add_grid_generator(grid_point(A));
+  gr_gs_needs_min.add_grid_generator(grid_line(3*B + C));
+  gr_gs_needs_min.add_grid_generator(grid_line(A - 2*B));
   print_generators(gr_gs_needs_min, "*** gr_gs_needs_min ***");
 
   Grid gr_cgs_needs_min(3);
-  gr_cgs_needs_min.add_congruence(2*A + B - 3*C - 2 == 0);
+  gr_cgs_needs_min.add_constraint(2*A + B - 3*C - 2 == 0);
   print_congruences(gr_cgs_needs_min, "*** gr_cgs_needs_min ***");
 
-  assert(copy_compare(gr_gs_min, gr_gs_needs_min));
-  assert(copy_compare(gr_gs_needs_min, gr_cgs_needs_min));
+  // Grids gr_gs_min, gr_gs_needs_min and gr_cgs_needs_min are the
+  // same grids.
 
   Linear_Expression le = 2*A + B - 3*C;
 
-  Grid_Generator exp_pnt1(grid_point(2*B + 0*C));
+  Generator exp_pnt1(point(2*B + 0*C));
 
   bool ok = check_maximize(gr_gs_min, le, 2, 1, exp_pnt1, "gr_gs_min")
     && check_minimize(gr_gs_min, le, 2, 1, exp_pnt1, "gr_gs_min");
@@ -418,7 +424,7 @@ test11() {
   ok &= check_maximize(gr_gs_needs_min, le, 2, 1, exp_pnt1, "gr_gs_needs_min")
     &&check_minimize(gr_gs_needs_min, le, 2, 1, exp_pnt1, "gr_gs_needs_min");
 
-  Grid_Generator exp_pnt2(grid_point(-2*C, 3));
+  Generator exp_pnt2(point(-2*C, 3));
 
   ok &= check_maximize(
           gr_cgs_needs_min, le, 2, 1, exp_pnt2, "gr_cgs_needs_min")
@@ -439,28 +445,28 @@ test12() {
   Variable F(5);
 
   Grid gr_gs_min(6, EMPTY);
-  gr_gs_min.add_generator_and_minimize(grid_point(7*A - 11*B + 19*F));
+  gr_gs_min.add_grid_generator_and_minimize(grid_point(7*A - 11*B + 19*F));
   print_generators(gr_gs_min, "*** gr_gs_min ***");
 
   Grid gr_gs_needs_min(6, EMPTY);
-  gr_gs_needs_min.add_generator(grid_point(7*A - 11*B + 19*F));
+  gr_gs_needs_min.add_grid_generator(grid_point(7*A - 11*B + 19*F));
   print_generators(gr_gs_needs_min, "*** gr_gs_needs_min ***");
 
   Grid gr_cgs_needs_min(6);
-  gr_cgs_needs_min.add_congruence(A == 7);
-  gr_cgs_needs_min.add_congruence(B == -11);
-  gr_cgs_needs_min.add_congruence(C == 0);
-  gr_cgs_needs_min.add_congruence(D == 0);
-  gr_cgs_needs_min.add_congruence(E == 0);
-  gr_cgs_needs_min.add_congruence(F == 19);
+  gr_cgs_needs_min.add_constraint(A == 7);
+  gr_cgs_needs_min.add_constraint(B == -11);
+  gr_cgs_needs_min.add_constraint(C == 0);
+  gr_cgs_needs_min.add_constraint(D == 0);
+  gr_cgs_needs_min.add_constraint(E == 0);
+  gr_cgs_needs_min.add_constraint(F == 19);
   print_congruences(gr_cgs_needs_min, "*** gr_cgs_needs_min ***");
 
-  assert(copy_compare(gr_gs_min, gr_gs_needs_min));
-  assert(copy_compare(gr_gs_needs_min, gr_cgs_needs_min));
+  // Grids gr_gs_min, gr_gs_needs_min and gr_cgs_needs_min are the
+  // same grids.
 
   Linear_Expression le = A + 2*B + 3*C + 4*D + 6*F;
 
-  Grid_Generator exp_pnt(grid_point(7*A - 11*B + 19*F));
+  Generator exp_pnt(point(7*A - 11*B + 19*F));
 
   bool ok = check_maximize(gr_gs_min, le, 99, 1, exp_pnt, "gr_gs_min")
     && check_minimize(gr_gs_min, le, 99, 1, exp_pnt, "gr_gs_min");
@@ -476,6 +482,23 @@ test12() {
   return ok;
 }
 
+// Unbounded grid in 1D where the generator system is up-to-date but
+// not minimized.
+bool
+test13() {
+  Variable A(0);
+
+  Grid gr(1, EMPTY);
+  gr.add_grid_generator(grid_point(A));
+  gr.add_grid_generator(grid_point(A, 2));
+  print_generators(gr, "*** gr generators before ***");
+
+  bool ok = check_both(gr, A, "gr");
+  print_generators(gr, "*** gr generators after ***");
+
+  return ok;
+}
+
 } // namespace
 
 BEGIN_MAIN
@@ -491,4 +514,5 @@ BEGIN_MAIN
   DO_TEST(test10);
   DO_TEST(test11);
   DO_TEST(test12);
+  DO_TEST(test13);
 END_MAIN
