@@ -1,12 +1,12 @@
 /* Test Grid::total_memory_in_bytes() and
    Grid::external_memory_in_bytes().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -38,10 +38,10 @@ add_congruence(Grid& gr, const Congruence& cg) {
 }
 
 void
-add_generator(Grid& gr, const Grid_Generator& g) {
+add_grid_generator(Grid& gr, const Grid_Generator& g) {
   const memory_size_type gr_memory_before = gr.total_memory_in_bytes();
   const memory_size_type g_memory = g.total_memory_in_bytes();
-  gr.add_generator(g);
+  gr.add_grid_generator(g);
   const memory_size_type gr_memory_after = gr.total_memory_in_bytes();
   nout << gr_memory_before
        << " + " << g_memory
@@ -52,7 +52,7 @@ add_generator(Grid& gr, const Grid_Generator& g) {
 void
 minimize(Grid& gr) {
   const memory_size_type gr_memory_before = gr.total_memory_in_bytes();
-  (void) gr.minimized_generators();
+  (void) gr.minimized_grid_generators();
   const memory_size_type gr_memory_after = gr.total_memory_in_bytes();
   nout << gr_memory_before
        << " -m-> " << gr_memory_after
@@ -142,7 +142,7 @@ test01() {
   const Congruence_System& cgs = gr1.congruences();
   const memory_size_type cgs_total_size = cgs.total_memory_in_bytes();
   const memory_size_type cgs_external_size = cgs.external_memory_in_bytes();
-  const Grid_Generator_System& gs = gr1.generators();
+  const Grid_Generator_System& gs = gr1.grid_generators();
   const memory_size_type gs_total_size = gs.total_memory_in_bytes();
   const memory_size_type gs_external_size = gs.external_memory_in_bytes();
 
@@ -168,7 +168,7 @@ test01() {
   unsigned n = 0;
   for (Grid_Generator_System::const_iterator i = gs.begin(),
 	 gs_end = gs.end(); i != gs_end; ++i) {
-    add_generator(gr2, *i);
+    add_grid_generator(gr2, *i);
     if (++n % 4 == 0)
       minimize(gr2);
   }
@@ -209,10 +209,10 @@ test02() {
   Variable z(2);
 
   Grid gr1(3);
-  gr1.add_constraint(4*x - 2*y - z + 14 >= 0);
-  gr1.add_constraint(4*x + 2*y - z + 2 >= 0);
-  gr1.add_constraint(x + y - 1 >= 0);
-  gr1.add_constraint(x + y + 2*z - 5 >= 0);
+  gr1.refine_with_constraint(4*x - 2*y - z + 14 >= 0);
+  gr1.refine_with_constraint(4*x + 2*y - z + 2 >= 0);
+  gr1.refine_with_constraint(x + y - 1 >= 0);
+  gr1.refine_with_constraint(x + y + 2*z - 5 >= 0);
 
   const memory_size_type gr1_total_size = gr1.total_memory_in_bytes();
   const memory_size_type gr1_external_size = gr1.external_memory_in_bytes();
@@ -231,32 +231,26 @@ test02() {
        << "dgr.external_memory_in_bytes() = " << dgr_external_size
        << endl;
 
-  Polyhedra_Powerset<Grid> pgr1(gr1);
+  Pointset_Powerset<Grid> pgr1(gr1);
 
   Grid gr2(3);
-  gr2.add_constraint(x >= 0);
-  gr2.add_constraint(y >= 0);
-  gr2.add_constraint(z >= 0);
-  gr2.add_constraint(x <= 1);
-  gr2.add_constraint(y <= 1);
-  gr2.add_constraint(z <= 1);
-  Polyhedra_Powerset<Grid> pgr2(gr2);
+  gr2.refine_with_constraint(x >= 0);
+  gr2.refine_with_constraint(y >= 0);
+  gr2.refine_with_constraint(z >= 0);
+  gr2.refine_with_constraint(x <= 1);
+  gr2.refine_with_constraint(y <= 1);
+  gr2.refine_with_constraint(z <= 1);
+  Pointset_Powerset<Grid> pgr2(gr2);
 
-  // TODO: Include these sections when poly_difference_assign is
-  //       defined for Grid.
-#if 0
-  Polyhedra_Powerset<Grid> p2gr2 = pgr2;
-  p2gr2.poly_difference_assign(pgr1);
-#endif
+  Pointset_Powerset<Grid> p2gr2 = pgr2;
+  p2gr2.difference_assign(pgr1);
 
   const memory_size_type pgr1_total_size = pgr1.total_memory_in_bytes();
   const memory_size_type pgr1_external_size = pgr1.external_memory_in_bytes();
   const memory_size_type pgr2_total_size = pgr2.total_memory_in_bytes();
   const memory_size_type pgr2_external_size = pgr2.external_memory_in_bytes();
-#if 0
   const memory_size_type p2gr2_total_size = p2gr2.total_memory_in_bytes();
   const memory_size_type p2gr2_external_size = p2gr2.external_memory_in_bytes();
-#endif
 
   nout << "pgr1.total_memory_in_bytes() = " << pgr1_total_size
        << endl
@@ -265,12 +259,10 @@ test02() {
        << "pgr2.total_memory_in_bytes() = " << pgr2_total_size
        << endl
        << "pgr2.external_memory_in_bytes() = " << pgr2_external_size
-#if 0
        << endl
        << "p2gr2.total_memory_in_bytes() = " << p2gr2_total_size
        << endl
        << "p2gr2.external_memory_in_bytes() = " << p2gr2_external_size
-#endif
        << endl;
 
   return true;
