@@ -1,11 +1,11 @@
 /* Test Grid::time_elapse_assign().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -119,7 +119,7 @@ test05() {
   print_congruences(gr1, "*** gr1 ***");
 
   Grid gr2(2, EMPTY);
-  gr2.add_generator(grid_point());
+  gr2.add_grid_generator(grid_point());
   print_generators(gr2, "*** gr2 ***");
 
   Grid known_gr(gr1);
@@ -140,11 +140,11 @@ test06() {
   Variable A(0);
 
   Grid gr1(1);
-  gr1.add_congruence(A == 2);
+  gr1.add_constraint(A == 2);
   print_congruences(gr1, "*** gr1 ***");
 
   Grid gr2(1);
-  gr2.add_congruence(A == 1);
+  gr2.add_constraint(A == 1);
   print_congruences(gr2, "*** gr2 ***");
 
   gr1.time_elapse_assign(gr2);
@@ -165,7 +165,7 @@ test07() {
   Variable A(0);
 
   Grid gr1(1);
-  gr1.add_congruence(A == 2);
+  gr1.add_constraint(A == 2);
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(1);
@@ -196,7 +196,7 @@ test08() {
 
   Grid gr2(2);
   gr2.add_congruence((A %= 0) / 2);
-  gr2.add_congruence(B == 0);
+  gr2.add_constraint(B == 0);
   print_congruences(gr2, "*** gr2 ***");
 
   gr1.time_elapse_assign(gr2);
@@ -220,22 +220,22 @@ test09() {
   Variable D(3);
 
   Grid gr1(4, EMPTY);
-  gr1.add_generator(grid_point());
-  gr1.add_generator(grid_point(2*A));
-  gr1.add_generator(grid_point(4*A));
-  gr1.add_generator(grid_point(D));
+  gr1.add_grid_generator(grid_point());
+  gr1.add_grid_generator(grid_point(2*A));
+  gr1.add_grid_generator(grid_point(4*A));
+  gr1.add_grid_generator(grid_point(D));
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(4, EMPTY);
-  gr2.add_generator(grid_point(A));
+  gr2.add_grid_generator(grid_point(A));
   print_generators(gr2, "*** gr2 ***");
 
   gr1.time_elapse_assign(gr2);
 
   Grid known_gr(4, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_point(A));
-  known_gr.add_generator(grid_point(D));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_point(A));
+  known_gr.add_grid_generator(grid_point(D));
 
   bool ok = (gr1 == known_gr);
 
@@ -251,7 +251,7 @@ test10() {
   Variable A(0);
 
   Grid gr1(1);
-  gr1.add_congruence(A == 2);
+  gr1.add_constraint(A == 2);
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(1);
@@ -274,7 +274,7 @@ test10() {
 bool
 test11() {
   Grid gr1(1, EMPTY);
-  gr1.add_generator(grid_point());
+  gr1.add_grid_generator(grid_point());
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(19, EMPTY);
@@ -285,11 +285,11 @@ test11() {
   }
   catch (const std::invalid_argument& e) {
     nout << "invalid_argument: " << e.what() << endl;
+    return true;
   }
   catch (...) {
-    return false;
   }
-  return true;
+  return false;
 }
 
 // Multi-dimension grids with denominators.
@@ -300,20 +300,20 @@ test12() {
   Variable C(2);
 
   Grid gr1(3, EMPTY);
-  gr1.add_generator(grid_point());
-  gr1.add_generator(grid_point(A + 2*B - 3*C, 3));
+  gr1.add_grid_generator(grid_point());
+  gr1.add_grid_generator(grid_point(A + 2*B - 3*C, 3));
   print_generators(gr1, "*** gr1 ***");
 
   Grid gr2(3, EMPTY);
-  gr2.add_generator(grid_point(3*A - B + 4*C, 7));
+  gr2.add_grid_generator(grid_point(3*A - B + 4*C, 7));
   print_generators(gr2, "*** gr2 ***");
 
   gr1.time_elapse_assign(gr2);
 
   Grid known_gr(3, EMPTY);
-  known_gr.add_generator(grid_point());
-  known_gr.add_generator(grid_point(A + 2*B - 3*C, 3));
-  known_gr.add_generator(grid_point(3*A - B + 4*C, 7));
+  known_gr.add_grid_generator(grid_point());
+  known_gr.add_grid_generator(grid_point(A + 2*B - 3*C, 3));
+  known_gr.add_grid_generator(grid_point(3*A - B + 4*C, 7));
 
   bool ok = (gr1 == known_gr);
 
