@@ -1,11 +1,11 @@
 /* Test operator<<(std::ostream&, const Congruence_System&).
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -21,6 +21,7 @@ For the most up-to-date information see the Parma Polyhedra Library
 site: http://www.cs.unipr.it/ppl/ . */
 
 #include "ppl_test.hh"
+#include <sstream>
 
 using namespace Parma_Polyhedra_Library::IO_Operators;
 
@@ -35,7 +36,7 @@ test01() {
 
   bool ok = (cgs.OK());
 
-  stringstream ss;
+  std::stringstream ss;
   ss << cgs;
   ok &= (!ss.str().compare("true"));
 
