@@ -1,11 +1,11 @@
 /* Test Polyhedron::add_generator().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -52,7 +52,7 @@ test01() {
 
   bool ok = (ph2 == known_result);
 
-  print_generators(ph2, "*** After ph2add_generator(*i) ***");
+  print_generators(ph2, "*** after ph2add_generator(*i) ***");
 
   return ok;
 }
@@ -83,7 +83,7 @@ test02() {
 
   bool ok = (ph2 == known_result);
 
-  print_generators(ph2, "*** After ph2.add_generator(*i) ***");
+  print_generators(ph2, "*** after ph2.add_generator(*i) ***");
 
   return ok;
 }
