@@ -1,11 +1,11 @@
 /* Test Polyhedron::affine_image().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -34,7 +34,7 @@ test01() {
   ph.add_constraint(C == -2);
   ph.add_constraint(A == 0);
 
-  print_constraints(ph, "--- ph ---");
+  print_constraints(ph, "*** ph ***");
 
   ph.affine_image(B, A+2, 1);
 
@@ -43,7 +43,7 @@ test01() {
 
   bool ok = (ph == known_result);
 
-  print_generators(ph, "--- ph after ph.affine_image(B, A+2, 1) ---");
+  print_generators(ph, "*** ph after ph.affine_image(B, A+2, 1) ***");
 
   return ok;
 }
@@ -58,7 +58,7 @@ test02() {
   ph.add_constraint(B >= 0);
   ph.add_constraint(A <= 3);
 
-  print_constraints(ph, "--- ph ---");
+  print_constraints(ph, "*** ph ***");
 
   ph.affine_image(A, A+B+1);
 
@@ -69,7 +69,7 @@ test02() {
 
   bool ok = (ph == known_result);
 
-  print_constraints(ph, "--- ph after ph.affine_image(A, A+B+1) ---");
+  print_constraints(ph, "*** ph after ph.affine_image(A, A+B+1) ***");
 
   return ok;
 }
@@ -95,7 +95,7 @@ test03() {
 
   bool ok = (ph == known_result);
 
-  print_generators(ph, "*** After ph.affine_image(A, A + 1, 2) ***");
+  print_generators(ph, "*** after ph.affine_image(A, A + 1, 2) ***");
 
   return ok;
 }
@@ -108,7 +108,7 @@ test04() {
   C_Polyhedron ph(2, EMPTY);
   ph.add_generator(point(A));
 
-  print_constraints(ph, "--- ph ---");
+  print_constraints(ph, "*** ph ***");
 
   ph.affine_image(A, B+2, -3);
 
@@ -117,7 +117,7 @@ test04() {
 
   bool ok = (ph == known_result);
 
-  print_generators(ph, "--- ph after ph.affine_image(A, B+2, -3) ---");
+  print_generators(ph, "*** ph after ph.affine_image(A, B+2, -3) ***");
 
   return ok;
 }
@@ -133,7 +133,7 @@ test05() {
   ph.add_constraint(B >= 1);
   ph.add_constraint(2*A >= B);
 
-  print_constraints(ph, "--- ph ---");
+  print_constraints(ph, "*** ph ***");
 
   ph.affine_image(B, A-B+2, -3);
 
@@ -145,7 +145,7 @@ test05() {
 
   bool ok = (ph == known_result);
 
-  print_generators(ph, "--- ph after ph.affine_image(B, A-B+2, -3) ---");
+  print_generators(ph, "*** ph after ph.affine_image(B, A-B+2, -3) ***");
 
   return ok;
 }
@@ -165,7 +165,7 @@ test06() {
 
   bool ok = (ph1 == known_result);
 
-  print_constraints(ph1, "*** After ph1.affine_image(A, 2*A + B + 1) ***");
+  print_constraints(ph1, "*** after ph1.affine_image(A, 2*A + B + 1) ***");
 
   return ok;
 }
@@ -195,7 +195,7 @@ test07() {
 
   bool ok = (ph == known_result);
 
-  print_generators(ph, "*** After ph.affine_image(A, -A - 1, -1) ***");
+  print_generators(ph, "*** after ph.affine_image(A, -A - 1, -1) ***");
 
   return ok;
 }
@@ -218,9 +218,9 @@ test08() {
 
   bool ok = (ph == copy_ph);
 
-  print_generators(ph, "*** After ph.affine_image(A, A + 1) ***");
+  print_generators(ph, "*** after ph.affine_image(A, A + 1) ***");
   print_generators(copy_ph,
-		   "*** After copy_ph.affine_image(A, -A - 1, -1) ***");
+		   "*** after copy_ph.affine_image(A, -A - 1, -1) ***");
 
   return ok;
 }
@@ -243,9 +243,9 @@ test09() {
 
   bool ok = (ph == copy_ph);
 
-  print_generators(ph, "*** After ph.affine_image(B, A + 1) ***");
+  print_generators(ph, "*** after ph.affine_image(B, A + 1) ***");
   print_generators(copy_ph,
-		   "*** After copy_ph.affine_image(B, -A - 1, -1) ***");
+		   "*** after copy_ph.affine_image(B, -A - 1, -1) ***");
 
   return ok;
 }
