@@ -1,11 +1,11 @@
 /* Test Polyhedron::generalized_affine_preimage().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -35,7 +35,7 @@ test01() {
   ph.add_generator(closure_point(2*A + 2*B));
   ph.add_generator(closure_point(3*A + B));
 
-  print_constraints(ph, "--- ph ---");
+  print_constraints(ph, "*** ph ***");
 
   // A longer way of computing the generalized affine preimage below.
   NNC_Polyhedron known_result(ph);
@@ -50,8 +50,8 @@ test01() {
 
   bool ok = (ph == known_result);
 
-  print_generators(ph, "--- ph after "
-		   "ph.generalized_affine_preimage(B, LESS_THAN, B+2) ---");
+  print_generators(ph, "*** ph after "
+		   "ph.generalized_affine_preimage(B, LESS_THAN, B+2) ***");
 
   return ok;
 }
