@@ -1,11 +1,11 @@
 /* Test Polyhedron::map_space_dimensions().
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -39,7 +39,7 @@ test01() {
 
   bool ok = (ph1 == known_result);
 
-  print_constraints(ph1, "*** After ph1.map_space_dimensions(function) ***");
+  print_constraints(ph1, "*** after ph1.map_space_dimensions(function) ***");
 
   return ok;
 }
@@ -59,7 +59,7 @@ test02() {
 
   bool ok = (ph1 == known_result);
 
-  print_constraints(ph1, "*** After ph1.map_space_dimensions(function) ***");
+  print_constraints(ph1, "*** after ph1.map_space_dimensions(function) ***");
 
   return ok;
 }
@@ -95,7 +95,7 @@ test03() {
 
   bool ok = (ph1 == known_result);
 
-  print_generators(ph1, "*** After ph1.map_space_dimensions(function) ***");
+  print_generators(ph1, "*** after ph1.map_space_dimensions(function) ***");
 
   return ok;
 }
@@ -130,7 +130,7 @@ test04() {
 
   bool ok = (ph1 == known_result);
 
-  print_generators(ph1, "*** After ph1.map_space_dimensions(function) ***");
+  print_generators(ph1, "*** after ph1.map_space_dimensions(function) ***");
 
   return ok;
 }
@@ -162,7 +162,7 @@ test05() {
 
   bool ok = (ph1 == known_result);
 
-  print_generators(ph1, "*** After ph1.map_space_dimensions(function) ***");
+  print_generators(ph1, "*** after ph1.map_space_dimensions(function) ***");
 
   return ok;
 }
@@ -192,7 +192,7 @@ test06() {
 
   bool ok = (ph1 == known_result);
 
-  print_generators(ph1, "*** After ph1.map_space_dimensions(function) ***");
+  print_generators(ph1, "*** after ph1.map_space_dimensions(function) ***");
 
   return ok;
 }
@@ -229,7 +229,7 @@ test07() {
 
   bool ok = (ph1 == known_result);
 
-  print_generators(ph1, "*** After ph1.map_space_dimensions(function) ***");
+  print_generators(ph1, "*** after ph1.map_space_dimensions(function) ***");
 
   return ok;
 }
@@ -263,7 +263,7 @@ test08() {
 
   bool ok = (ph1 == known_result);
 
-  print_generators(ph1, "*** After ph1.map_space_dimensions(function) ***");
+  print_generators(ph1, "*** after ph1.map_space_dimensions(function) ***");
 
   return ok;
 }
@@ -285,7 +285,7 @@ test09() {
 
   bool ok = (ph1 == known_result);
 
-  print_constraints(ph1, "*** After ph1.map_space_dimensions(function) ***");
+  print_constraints(ph1, "*** after ph1.map_space_dimensions(function) ***");
 
   return ok;
 }
@@ -388,7 +388,7 @@ test11() {
 
   bool ok = (ph == known_result);
 
-  print_constraints(ph, "*** After ph.map_space_dimensions(rotate_right) ***");
+  print_constraints(ph, "*** after ph.map_space_dimensions(rotate_right) ***");
 
   return ok;
 }
@@ -415,7 +415,44 @@ test12() {
 
   bool ok = (ph == known_result);
 
-  print_constraints(ph, "*** After ph.map_space_dimensions(rotate_right) ***");
+  print_constraints(ph, "*** after ph.map_space_dimensions(rotate_right) ***");
+
+  return ok;
+}
+
+bool
+test13() {
+  Variable A(0);
+  Variable B(1);
+  Variable C(2);
+  Variable D(3);
+
+  Partial_Function function;
+  function.insert(0, 2);
+  function.insert(1, 3);
+
+  Generator_System gs;
+  gs.insert(point());
+  gs.insert(point(A));
+  gs.insert(point(2*B));
+  gs.insert(point(A + 2*B));
+
+  C_Polyhedron ph1(gs);
+
+  print_function(function, "*** function ***");
+  print_generators(ph1, "*** ph1 ***");
+
+  ph1.map_space_dimensions(function);
+
+  C_Polyhedron known_result(4, EMPTY);
+  known_result.add_generator(point());
+  known_result.add_generator(point(C));
+  known_result.add_generator(point(2*D));
+  known_result.add_generator(point(C + 2*D));
+
+  bool ok = (ph1 == known_result);
+
+  print_generators(ph1, "*** after ph1.map_space_dimensions(function) ***");
 
   return ok;
 }
@@ -440,4 +477,5 @@ BEGIN_MAIN
 #endif // !defined(DERIVED_TEST)
   DO_TEST(test11);
   DO_TEST(test12);
+  DO_TEST(test13);
 END_MAIN
