@@ -1,11 +1,11 @@
 /* SEND + MORE = MONEY.
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -22,13 +22,15 @@ site: http://www.cs.unipr.it/ppl/ . */
 
 #include "ppl_test.hh"
 
-using namespace Parma_Polyhedra_Library::IO_Operators;
-
 namespace Parma_Polyhedra_Library {
   // Import all the output operators into the main PPL namespace.
   using IO_Operators::operator<<;
 }
 
+namespace {
+
+namespace test01_namespace {
+
 // The classic cryptarithmetic puzzle:
 //
 //      S E N D
@@ -36,8 +38,6 @@ namespace Parma_Polyhedra_Library {
 //    ---------
 //    M O N E Y
 
-namespace {
-
 void
 less_than(C_Polyhedron& ph, Variable X, Variable Y) {
   ph.add_constraint(X+1 <= Y);
@@ -90,12 +90,10 @@ constraints(C_Polyhedron& ph,
   less_than(ph, R, S);
 }
 
-} // namespace
-
-int
-main() TRY {
-  set_handlers();
+} // namespace test01_namespace
 
+bool
+test01() {
   Variable S(0);
   Variable E(1);
   Variable N(2);
@@ -112,38 +110,42 @@ main() TRY {
       for (int C3 = 0; C3 <= 1; ++C3)
 	for (int C4 = 0; C4 <= 1; ++C4) {
 	  C_Polyhedron ph(8);
-	  constraints(ph,
-		      S, E, N, D, M, O, R, Y,
-		      C1, C2, C3, C4);
-	  if (!ph.is_empty()) {
-	    nout << "Solution constraints" << endl;
-	    const Constraint_System& cs = ph.constraints();
-	    std::copy(cs.begin(), cs.end(),
-		      std::ostream_iterator<Constraint>(nout, "\n"));
-	    nout << "Solution generators" << endl;
-	    const Generator_System& gs = ph.generators();
-	    std::copy(gs.begin(), gs.end(),
-		      std::ostream_iterator<Generator>(nout, "\n"));
+	  test01_namespace::constraints(ph,
+					S, E, N, D, M, O, R, Y,
+					C1, C2, C3, C4);
+	  if (ph.is_empty())
+	    continue;
 
-	    if (solution_found)
-	      return 1;
+	  nout << "Solution constraints" << endl;
+	  const Constraint_System& cs = ph.constraints();
+	  std::copy(cs.begin(), cs.end(),
+		    std::ostream_iterator<Constraint>(nout, "\n"));
+	  nout << "Solution generators" << endl;
+	  const Generator_System& gs = ph.generators();
+	  std::copy(gs.begin(), gs.end(),
+		    std::ostream_iterator<Generator>(nout, "\n"));
+	  if (solution_found)
+	    return true;
+	  solution_found = true;
 
-	    solution_found = true;
+	  C_Polyhedron expected(8);
+	  expected.add_constraint(S == 9);
+	  expected.add_constraint(E == 5);
+	  expected.add_constraint(N == 6);
+	  expected.add_constraint(D == 7);
+	  expected.add_constraint(M == 1);
+	  expected.add_constraint(O == 0);
+	  expected.add_constraint(R == 8);
+	  expected.add_constraint(Y == 2);
 
-	    C_Polyhedron expected(8);
-	    expected.add_constraint(S == 9);
-	    expected.add_constraint(E == 5);
-	    expected.add_constraint(N == 6);
-	    expected.add_constraint(D == 7);
-	    expected.add_constraint(M == 1);
-	    expected.add_constraint(O == 0);
-	    expected.add_constraint(R == 8);
-	    expected.add_constraint(Y == 2);
-
-	    if (ph != expected)
-	      return 1;
-	  }
+	  if (ph != expected)
+	    return false;
 	}
-  return 0;
+  return true;
 }
-CATCH
+
+} // namespace
+
+BEGIN_MAIN
+  DO_TEST_F8(test01);
+END_MAIN
