@@ -1,11 +1,11 @@
 /* Test the function is_universe() for a NNC_polyhedron.
-   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2009 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -36,10 +36,10 @@ test01() {
   Constraint_System cs;
   NNC_Polyhedron ph4(cs);
 
-  print_constraints(ph1, "--- ph1 ---");
-  print_constraints(ph2, "--- ph2 ---");
-  print_constraints(ph3, "--- ph3 ---");
-  print_constraints(ph4, "--- ph4 ---");
+  print_constraints(ph1, "*** ph1 ***");
+  print_constraints(ph2, "*** ph2 ***");
+  print_constraints(ph3, "*** ph3 ***");
+  print_constraints(ph4, "*** ph4 ***");
 
   bool universe1 = ph1.is_universe();
 
